package docker

import (
	"github.com/c-bata/go-prompt"
)

var MajorCommands = []prompt.Suggest{
	{Text: "app", Description: "A tool to build and manage Docker Applications"},
	{Text: "attach", Description: "Attach local standard input, output, and error streams to a running container"},
	{Text: "build", Description: "Build an image from a Dockerfile"},
	{Text: "builder", Description: "Manage builds"},
	{Text: "buildx", Description: "Build with BuildKit"},
	{Text: "checkpoint", Description: "Manage checkpoints"},
	{Text: "cluster", Description: "A tool to build and manage Docker Clusters."},
	{Text: "commit", Description: "Create a new image from a container's changes"},
	{Text: "compose", Description: "Docker Compose"},
	{Text: "config", Description: "Manage Docker configs"},
	{Text: "container", Description: "Manage containers"},
	{Text: "context", Description: "Manage contexts"},
	{Text: "cp", Description: "Copy files/folders between a container and the local filesystem"},
	{Text: "create", Description: "Create a new container"},
	{Text: "diff", Description: "Inspect changes to files or directories on a container's filesystem"},
	{Text: "events", Description: "Get real time events from the server"},
	{Text: "exec", Description: "Run a command in a running container"},
	{Text: "export", Description: "Export a container's filesystem as a tar archive"},
	{Text: "history", Description: "Show the history of an image"},
	{Text: "image", Description: "Manage images"},
	{Text: "images", Description: "List images"},
	{Text: "import", Description: "Import the contents from a tarball to create a filesystem image"},
	{Text: "info", Description: "Display system-wide information"},
	{Text: "inspect", Description: "Return low-level information on Docker objects"},
	{Text: "kill", Description: "Kill one or more running containers"},
	{Text: "load", Description: "Load an image from a tar archive or STDIN"},
	{Text: "login", Description: "Log in to a Docker registry"},
	{Text: "logout", Description: "Log out from a Docker registry"},
	{Text: "logs", Description: "Fetch the logs of a container"},
	{Text: "manifest", Description: "Manage Docker image manifests and manifest lists"},
	{Text: "network", Description: "Manage networks"},
	{Text: "node", Description: "Manage Swarm nodes"},
	{Text: "pause", Description: "Pause all processes within one or more containers"},
	{Text: "plugin", Description: "Manage plugins"},
	{Text: "port", Description: "List port mappings or a specific mapping for the container"},
	{Text: "ps", Description: "List containers"},
	{Text: "pull", Description: "Pull an image or a repository from a registry"},
	{Text: "push", Description: "Push an image or a repository to a registry"},
	{Text: "rename", Description: "Rename a container"},
	{Text: "restart", Description: "Restart one or more containers"},
	{Text: "rm", Description: "Remove one or more containers"},
	{Text: "rmi", Description: "Remove one or more images"},
	{Text: "run", Description: "Run a command in a new container"},
	{Text: "save", Description: "Save one or more images to a tar archive (streamed to STDOUT by default)"},
	{Text: "search", Description: "Search the Docker Hub for images"},
	{Text: "secret", Description: "Manage Docker secrets"},
	{Text: "service", Description: "Manage services"},
	{Text: "stack", Description: "Manage Docker stacks"},
	{Text: "start", Description: "Start one or more stopped containers"},
	{Text: "stats", Description: "Display a live stream of container(s) resource usage statistics"},
	{Text: "stop", Description: "Stop one or more running containers"},
	{Text: "swarm", Description: "Manage Swarm"},
	{Text: "system", Description: "Manage Docker"},
	{Text: "tag", Description: "Create a tag TARGET_IMAGE that refers to SOURCE_IMAGE"},
	{Text: "top", Description: "Display the running processes of a container"},
	{Text: "trust", Description: "Manage trust on Docker images"},
	{Text: "unpause", Description: "Unpause all processes within one or more containers"},
	{Text: "update", Description: "Update configuration of one or more containers"},
	{Text: "version", Description: "Show the Docker version information"},
	{Text: "volume", Description: "Manage volumes"},
	{Text: "wait", Description: "Block until one or more containers stop, then print their exit codes"},
}

var subCommands = map[string][]prompt.Suggest{
	"app": {
		{Text: "bundle", Description: "Create a CNAB invocation image and bundle.json for the application"},
		{Text: "completion", Description: "Generates completion scripts for the specified shell (bash or zsh)"},
		{Text: "init", Description: "Initialize Docker Application definition"},
		{Text: "inspect", Description: "Shows metadata, parameters and a summary of the Compose file for a given application"},
		{Text: "install", Description: "Install an application"},
		{Text: "list", Description: "List the installations and their last known installation result"},
		{Text: "pull", Description: "Pull an application package from a registry"},
		{Text: "push", Description: "Push an application package to a registry"},
		{Text: "render", Description: "Render the Compose file for an Application Package"},
		{Text: "status", Description: "Get the installation status of an application"},
		{Text: "uninstall", Description: "Uninstall an application"},
		{Text: "upgrade", Description: "Upgrade an installed application"},
		{Text: "validate", Description: "Checks the rendered application is syntactically correct"},
		{Text: "version", Description: "Print version information"},
	},
	"builder": {
		{Text: "build", Description: "Build an image from a Dockerfile"},
		{Text: "prune", Description: "Remove build cache"},
	},
	"buildx": {
		{Text: "bake", Description: "Build from a file"},
		{Text: "build", Description: "Start a build"},
		{Text: "create", Description: "Create a new builder instance"},
		{Text: "du", Description: "Disk usage"},
		{Text: "imagetools", Description: "Commands to work on images in registry"},
		{Text: "inspect", Description: "Inspect current builder instance"},
		{Text: "ls", Description: "List builder instances"},
		{Text: "prune", Description: "Remove build cache"},
		{Text: "rm", Description: "Remove a builder instance"},
		{Text: "stop", Description: "Stop builder instance"},
		{Text: "use", Description: "Set the current builder instance"},
		{Text: "version", Description: "Show buildx version information"},
	},
	"checkpoint": {
		{Text: "create", Description: "Create a checkpoint from a running container"},
		{Text: "ls", Description: "List checkpoints for a container"},
		{Text: "rm", Description: "Remove a checkpoint"},
	},
	"cluster": {
		{Text: "backup", Description: "Backup a running cluster"},
		{Text: "create", Description: "Create a new Docker Cluster"},
		{Text: "inspect", Description: "Display detailed information about a cluster"},
		{Text: "ls", Description: "List all available clusters"},
		{Text: "restore", Description: "Restore a cluster from a backup"},
		{Text: "rm", Description: "Remove a cluster"},
		{Text: "update", Description: "Update a running cluster's desired state"},
		{Text: "version", Description: "Print Version, Commit, and Build type"},
	},
	"compose": {
		{Text: "build", Description: "Build or rebuild services"},
		{Text: "convert", Description: "Converts the compose file to platform's canonical format"},
		{Text: "create", Description: "Creates containers for a service."},
		{Text: "down", Description: "Stop and remove containers, networks"},
		{Text: "events", Description: "Receive real time events from containers."},
		{Text: "exec", Description: "Execute a command in a running container."},
		{Text: "kill", Description: "Force stop service containers."},
		{Text: "logs", Description: "View output from containers"},
		{Text: "ls", Description: "List running compose projects"},
		{Text: "pause", Description: "pause services"},
		{Text: "ps", Description: "List containers"},
		{Text: "pull", Description: "Pull service images"},
		{Text: "push", Description: "Push service images"},
		{Text: "rm", Description: "Removes stopped service containers"},
		{Text: "run", Description: "Run a one-off command on a service."},
		{Text: "start", Description: "Start services"},
		{Text: "stop", Description: "Stop services"},
		{Text: "top", Description: "Display the running processes"},
		{Text: "unpause", Description: "unpause services"},
		{Text: "up", Description: "Create and start containers"},
	},
	"config": {
		{Text: "create", Description: "Create a config from a file or STDIN"},
		{Text: "inspect", Description: "Display detailed information on one or more configs"},
		{Text: "ls", Description: "List configs"},
		{Text: "rm", Description: "Remove one or more configs"},
	},
	"container": {
		{Text: "attach", Description: "Attach local standard input, output, and error streams to a running container"},
		{Text: "commit", Description: "Create a new image from a container's changes"},
		{Text: "cp", Description: "Copy files/folders between a container and the local filesystem"},
		{Text: "create", Description: "Create a new container"},
		{Text: "diff", Description: "Inspect changes to files or directories on a container's filesystem"},
		{Text: "exec", Description: "Run a command in a running container"},
		{Text: "export", Description: "Export a container's filesystem as a tar archive"},
		{Text: "inspect", Description: "Display detailed information on one or more containers"},
		{Text: "kill", Description: "Kill one or more running containers"},
		{Text: "logs", Description: "Fetch the logs of a container"},
		{Text: "ls", Description: "List containers"},
		{Text: "pause", Description: "Pause all processes within one or more containers"},
		{Text: "port", Description: "List port mappings or a specific mapping for the container"},
		{Text: "prune", Description: "Remove all stopped containers"},
		{Text: "rename", Description: "Rename a container"},
		{Text: "restart", Description: "Restart one or more containers"},
		{Text: "rm", Description: "Remove one or more containers"},
		{Text: "run", Description: "Run a command in a new container"},
		{Text: "start", Description: "Start one or more stopped containers"},
		{Text: "stats", Description: "Display a live stream of container(s) resource usage statistics"},
		{Text: "stop", Description: "Stop one or more running containers"},
		{Text: "top", Description: "Display the running processes of a container"},
		{Text: "unpause", Description: "Unpause all processes within one or more containers"},
		{Text: "update", Description: "Update configuration of one or more containers"},
		{Text: "wait", Description: "Block until one or more containers stop, then print their exit codes"},
	},
	"context": {
		{Text: "create", Description: "Create a context"},
		{Text: "export", Description: "Export a context to a tar or kubeconfig file"},
		{Text: "import", Description: "Import a context from a tar or zip file"},
		{Text: "inspect", Description: "Display detailed information on one or more contexts"},
		{Text: "ls", Description: "List contexts"},
		{Text: "rm", Description: "Remove one or more contexts"},
		{Text: "update", Description: "Update a context"},
		{Text: "use", Description: "Set the current docker context"},
	},
	"image": {
		{Text: "build", Description: "Build an image from a Dockerfile"},
		{Text: "history", Description: "Show the history of an image"},
		{Text: "import", Description: "Import the contents from a tarball to create a filesystem image"},
		{Text: "inspect", Description: "Display detailed information on one or more images"},
		{Text: "load", Description: "Load an image from a tar archive or STDIN"},
		{Text: "ls", Description: "List images"},
		{Text: "prune", Description: "Remove unused images"},
		{Text: "pull", Description: "Pull an image or a repository from a registry"},
		{Text: "push", Description: "Push an image or a repository to a registry"},
		{Text: "rm", Description: "Remove one or more images"},
		{Text: "save", Description: "Save one or more images to a tar archive (streamed to STDOUT by default)"},
		{Text: "tag", Description: "Create a tag TARGET_IMAGE that refers to SOURCE_IMAGE"},
	},
	"manifest": {
		{Text: "annotate", Description: "Add additional information to a local image manifest"},
		{Text: "create", Description: "Create a local manifest list for annotating and pushing to a registry"},
		{Text: "inspect", Description: "Display an image manifest, or manifest list"},
		{Text: "push", Description: "Push a manifest list to a repository"},
		{Text: "rm", Description: "Delete one or more manifest lists from local storage"},
	},
	"network": {
		{Text: "connect", Description: "Connect a container to a network"},
		{Text: "create", Description: "Create a network"},
		{Text: "disconnect", Description: "Disconnect a container from a network"},
		{Text: "inspect", Description: "Display detailed information on one or more networks"},
		{Text: "ls", Description: "List networks"},
		{Text: "prune", Description: "Remove all unused networks"},
		{Text: "rm", Description: "Remove one or more networks"},
	},
	"node": {
		{Text: "demote", Description: "Demote one or more nodes from manager in the swarm"},
		{Text: "inspect", Description: "Display detailed information on one or more nodes"},
		{Text: "ls", Description: "List nodes in the swarm"},
		{Text: "promote", Description: "Promote one or more nodes to manager in the swarm"},
		{Text: "ps", Description: "List tasks running on one or more nodes, defaults to current node"},
		{Text: "rm", Description: "Remove one or more nodes from the swarm"},
		{Text: "update", Description: "Update a node"},
	},
	"plugin": {
		{Text: "create", Description: "Create a plugin from a rootfs and configuration. Plugin data directory must contain config.json and rootfs directory."},
		{Text: "disable", Description: "Disable a plugin"},
		{Text: "enable", Description: "Enable a plugin"},
		{Text: "inspect", Description: "Display detailed information on one or more plugins"},
		{Text: "install", Description: "Install a plugin"},
		{Text: "ls", Description: "List plugins"},
		{Text: "push", Description: "Push a plugin to a registry"},
		{Text: "rm", Description: "Remove one or more plugins"},
		{Text: "set", Description: "Change settings for a plugin"},
		{Text: "upgrade", Description: "Upgrade an existing plugin"},
	},
	"secret": {
		{Text: "create", Description: "Create a secret from a file or STDIN as content"},
		{Text: "inspect", Description: "Display detailed information on one or more secrets"},
		{Text: "ls", Description: "List secrets"},
		{Text: "rm", Description: "Remove one or more secrets"},
	},
	"service": {
		{Text: "create", Description: "Create a new service"},
		{Text: "inspect", Description: "Display detailed information on one or more services"},
		{Text: "logs", Description: "Fetch the logs of a service or task"},
		{Text: "ls", Description: "List services"},
		{Text: "ps", Description: "List the tasks of one or more services"},
		{Text: "rm", Description: "Remove one or more services"},
		{Text: "rollback", Description: "Revert changes to a service's configuration"},
		{Text: "scale", Description: "Scale one or multiple replicated services"},
		{Text: "update", Description: "Update a service"},
	},
	"stack": {
		{Text: "deploy", Description: "Deploy a new stack or update an existing stack"},
		{Text: "ls", Description: "List stacks"},
		{Text: "ps", Description: "List the tasks in the stack"},
		{Text: "rm", Description: "Remove one or more stacks"},
		{Text: "services", Description: "List the services in the stack"},
	},
	"swarm": {
		{Text: "ca", Description: "Display and rotate the root CA"},
		{Text: "init", Description: "Initialize a swarm"},
		{Text: "join", Description: "Join a swarm as a node and/or manager"},
		{Text: "join-token", Description: "Manage join tokens"},
		{Text: "leave", Description: "Leave the swarm"},
		{Text: "unlock", Description: "Unlock swarm"},
		{Text: "unlock-key", Description: "Manage the unlock key"},
		{Text: "update", Description: "Update the swarm"},
	},
	"system": {
		{Text: "df", Description: "Show docker disk usage"},
		{Text: "events", Description: "Get real time events from the server"},
		{Text: "info", Description: "Display system-wide information"},
		{Text: "prune", Description: "Remove unused data"},
	},
	"trust": {
		{Text: "inspect", Description: "Return low-level information about keys and signatures"},
		{Text: "key", Description: "Manage keys for signing Docker images"},
		{Text: "revoke", Description: "Remove trust for an image"},
		{Text: "sign", Description: "Sign an image"},
		{Text: "signer", Description: "Manage entities who can sign Docker images"},
	},
	"volume": {
		{Text: "create", Description: "Create a volume"},
		{Text: "inspect", Description: "Display detailed information on one or more volumes"},
		{Text: "ls", Description: "List volumes"},
		{Text: "prune", Description: "Remove all unused local volumes"},
		{Text: "rm", Description: "Remove one or more volumes"},
	},
	"x-batch": {
		{Text: "container", Description: "Batch operate containers"},
		{Text: "image", Description: "Batch operate images"},
	},
}

var optionsDocker = map[string][]prompt.Suggest{
	"global": {
		prompt.Suggest{Text: "--config", Description: "Location of client config files (default \"/root/.docker\")"},
		prompt.Suggest{Text: "--context", Alias: "-c", Description: "Name of the context to use to connect to the daemon (overrides DOCKER_HOST env var and default context set with \"docker context use\")"},
		prompt.Suggest{Text: "--debug", Alias: "-D", Description: "Enable debug mode"},
		prompt.Suggest{Text: "--help", Description: "Print usage"},
		prompt.Suggest{Text: "--host", Alias: "-H", Description: "Daemon socket(s) to connect to (default [])"},
		prompt.Suggest{Text: "--log-level", Alias: "-l", Description: "Set the logging level (\"debug\"|\"info\"|\"warn\"|\"error\"|\"fatal\") (default \"info\")"},
		prompt.Suggest{Text: "--tls", Description: "Use TLS; implied by --tlsverify"},
		prompt.Suggest{Text: "--tlscacert", Description: "Trust certs signed only by this CA (default \"/root/.docker/ca.pem\")"},
		prompt.Suggest{Text: "--tlscert", Description: "Path to TLS certificate file (default \"/root/.docker/cert.pem\")"},
		prompt.Suggest{Text: "--tlskey", Description: "Path to TLS key file (default \"/root/.docker/key.pem\")"},
		prompt.Suggest{Text: "--tlsverify", Description: "Use TLS and verify the remote"},
		prompt.Suggest{Text: "--version", Alias: "-v", Description: "Print version information and quit"},
	},
	"attach": {
		prompt.Suggest{Text: "--detach-keys", Description: "Override the key sequence for detaching a container"},
		prompt.Suggest{Text: "--no-stdin", Description: "Do not attach STDIN"},
		prompt.Suggest{Text: "--sig-proxy", Description: "Proxy all received signals to the process"},
	},
	"build": {
		prompt.Suggest{Text: "--add-host", Description: "Add a custom host-to-IP mapping (host:ip)"},
		prompt.Suggest{Text: "--build-arg", Description: "Set build-time variables"},
		prompt.Suggest{Text: "--cache-from", Description: "Images to consider as cache sources"},
		prompt.Suggest{Text: "--cgroup-parent", Description: "Optional parent cgroup for the container"},
		prompt.Suggest{Text: "--compress", Description: "Compress the build context using gzip"},
		prompt.Suggest{Text: "--cpu-period", Description: "Limit the CPU CFS (Completely Fair Scheduler) period"},
		prompt.Suggest{Text: "--cpu-quota", Description: "Limit the CPU CFS (Completely Fair Scheduler) quota"},
		prompt.Suggest{Text: "--cpu-shares", Alias: "-c", Description: "CPU shares (relative weight)"},
		prompt.Suggest{Text: "--cpuset-cpus", Description: "CPUs in which to allow execution (0-3, 0,1)"},
		prompt.Suggest{Text: "--cpuset-mems", Description: "MEMs in which to allow execution (0-3, 0,1)"},
		prompt.Suggest{Text: "--disable-content-trust", Description: "Skip image verification"},
		prompt.Suggest{Text: "--file", Alias: "-f", Description: "Name of the Dockerfile (Default is ‘PATH/Dockerfile’)"},
		prompt.Suggest{Text: "--force-rm", Description: "Always remove intermediate containers"},
		prompt.Suggest{Text: "--iidfile", Description: "Write the image ID to the file"},
		prompt.Suggest{Text: "--isolation", Description: "Container isolation technology"},
		prompt.Suggest{Text: "--label", Description: "Set metadata for an image"},
		prompt.Suggest{Text: "--memory", Alias: "-m", Description: "Memory limit"},
		prompt.Suggest{Text: "--memory-swap", Description: "Swap limit equal to memory plus swap: ‘-1’ to enable unlimited swap"},
		prompt.Suggest{Text: "--network", Description: "Set the networking mode for the RUN instructions during build"},
		prompt.Suggest{Text: "--no-cache", Description: "Do not use cache when building the image"},
		prompt.Suggest{Text: "--output", Alias: "-o", Description: "Output destination (format: type=local,dest=path)"},
		prompt.Suggest{Text: "--platform", Description: "Set platform if server is multi-platform capable"},
		prompt.Suggest{Text: "--progress", Description: "Set type of progress output (auto, plain, tty). Use plain to show container output"},
		prompt.Suggest{Text: "--pull", Description: "Always attempt to pull a newer version of the image"},
		prompt.Suggest{Text: "--quiet", Alias: "-q", Description: "Suppress the build output and print image ID on success"},
		prompt.Suggest{Text: "--rm", Description: "Remove intermediate containers after a successful build"},
		prompt.Suggest{Text: "--secret", Description: "Secret file to expose to the build (only if BuildKit enabled): id=mysecret,src=/local/secret"},
		prompt.Suggest{Text: "--security-opt", Description: "Security options"},
		prompt.Suggest{Text: "--shm-size", Description: "Size of /dev/shm"},
		prompt.Suggest{Text: "--squash", Description: "Squash newly built layers into a single new layer"},
		prompt.Suggest{Text: "--ssh", Description: "SSH agent socket or keys to expose to the build (only if BuildKit enabled) (format: default|<id>[=<socket>|<key>[,<key>]])"},
		prompt.Suggest{Text: "--stream", Description: "Stream attaches to server to negotiate build context"},
		prompt.Suggest{Text: "--tag", Alias: "-t", Description: "Name and optionally a tag in the ‘name:tag’ format"},
		prompt.Suggest{Text: "--target", Description: "Set the target build stage to build."},
		prompt.Suggest{Text: "--ulimit", Description: "Ulimit options"},
	},
	"commit": {
		prompt.Suggest{Text: "--author", Alias: "-a", Description: "Author (e.g., “John Hannibal Smith "},
		prompt.Suggest{Text: "--change", Alias: "-c", Description: "Apply Dockerfile instruction to the created image"},
		prompt.Suggest{Text: "--message", Alias: "-m", Description: "Commit message"},
		prompt.Suggest{Text: "--pause", Alias: "-p", Description: "Pause container during commit"},
	},
	"cp": {
		prompt.Suggest{Text: "--archive", Alias: "-a", Description: "Archive mode (copy all uid/gid information)"},
		prompt.Suggest{Text: "--follow-link", Alias: "-L", Description: "Always follow symbol link in SRC_PATH"},
	},
	"create": {
		prompt.Suggest{Text: "--add-host", Description: "Add a custom host-to-IP mapping (host:ip)"},
		prompt.Suggest{Text: "--attach", Alias: "-a", Description: "Attach to STDIN, STDOUT or STDERR"},
		prompt.Suggest{Text: "--blkio-weight", Description: "Block IO (relative weight), between 10 and 1000, or 0 to disable (default 0)"},
		prompt.Suggest{Text: "--blkio-weight-device", Description: "Block IO weight (relative device weight)"},
		prompt.Suggest{Text: "--cap-add", Description: "Add Linux capabilities"},
		prompt.Suggest{Text: "--cap-drop", Description: "Drop Linux capabilities"},
		prompt.Suggest{Text: "--cgroup-parent", Description: "Optional parent cgroup for the container"},
		prompt.Suggest{Text: "--cgroupns", Description: "Cgroup namespace to use (host|private)"},
		prompt.Suggest{Text: "--cidfile", Description: "Write the container ID to the file"},
		prompt.Suggest{Text: "--cpu-count", Description: "CPU count (Windows only)"},
		prompt.Suggest{Text: "--cpu-percent", Description: "CPU percent (Windows only)"},
		prompt.Suggest{Text: "--cpu-period", Description: "Limit CPU CFS (Completely Fair Scheduler) period"},
		prompt.Suggest{Text: "--cpu-quota", Description: "Limit CPU CFS (Completely Fair Scheduler) quota"},
		prompt.Suggest{Text: "--cpu-rt-period", Description: "Limit CPU real-time period in microseconds"},
		prompt.Suggest{Text: "--cpu-rt-runtime", Description: "Limit CPU real-time runtime in microseconds"},
		prompt.Suggest{Text: "--cpu-shares", Alias: "-c", Description: "CPU shares (relative weight)"},
		prompt.Suggest{Text: "--cpus", Description: "Number of CPUs"},
		prompt.Suggest{Text: "--cpuset-cpus", Description: "CPUs in which to allow execution (0-3, 0,1)"},
		prompt.Suggest{Text: "--cpuset-mems", Description: "MEMs in which to allow execution (0-3, 0,1)"},
		prompt.Suggest{Text: "--device", Description: "Add a host device to the container"},
		prompt.Suggest{Text: "--device-cgroup-rule", Description: "Add a rule to the cgroup allowed devices list"},
		prompt.Suggest{Text: "--device-read-bps", Description: "Limit read rate (bytes per second) from a device"},
		prompt.Suggest{Text: "--device-read-iops", Description: "Limit read rate (IO per second) from a device"},
		prompt.Suggest{Text: "--device-write-bps", Description: "Limit write rate (bytes per second) to a device"},
		prompt.Suggest{Text: "--device-write-iops", Description: "Limit write rate (IO per second) to a device"},
		prompt.Suggest{Text: "--disable-content-trust", Description: "Skip image verification"},
		prompt.Suggest{Text: "--dns", Description: "Set custom DNS servers"},
		prompt.Suggest{Text: "--dns-opt", Description: "Set DNS options"},
		prompt.Suggest{Text: "--dns-option", Description: "Set DNS options"},
		prompt.Suggest{Text: "--dns-search", Description: "Set custom DNS search domains"},
		prompt.Suggest{Text: "--domainname", Description: "Container NIS domain name"},
		prompt.Suggest{Text: "--entrypoint", Description: "Overwrite the default ENTRYPOINT of the image"},
		prompt.Suggest{Text: "--env", Alias: "-e", Description: "Set environment variables"},
		prompt.Suggest{Text: "--env-file", Description: "Read in a file of environment variables"},
		prompt.Suggest{Text: "--expose", Description: "Expose a port or a range of ports"},
		prompt.Suggest{Text: "--gpus", Description: "GPU devices to add to the container ('all' to pass all GPUs)"},
		prompt.Suggest{Text: "--group-add", Description: "Add additional groups to join"},
		prompt.Suggest{Text: "--health-cmd", Description: "Command to run to check health"},
		prompt.Suggest{Text: "--health-interval", Description: "Time between running the check (ms|s|m|h) (default 0s)"},
		prompt.Suggest{Text: "--health-retries", Description: "Consecutive failures needed to report unhealthy"},
		prompt.Suggest{Text: "--health-start-period", Description: "Start period for the container to initialize before starting health-retries countdown (ms|s|m|h) (default 0s)"},
		prompt.Suggest{Text: "--health-timeout", Description: "Maximum time to allow one check to run (ms|s|m|h) (default 0s)"},
		prompt.Suggest{Text: "--help", Description: "Print usage"},
		prompt.Suggest{Text: "--hostname", Alias: "-h", Description: "Container host name"},
		prompt.Suggest{Text: "--init", Description: "Run an init inside the container that forwards signals and reaps processes"},
		prompt.Suggest{Text: "--interactive", Alias: "-i", Description: "Keep STDIN open even if not attached"},
		prompt.Suggest{Text: "--io-maxbandwidth", Description: "Maximum IO bandwidth limit for the system drive (Windows only)"},
		prompt.Suggest{Text: "--io-maxiops", Description: "Maximum IOps limit for the system drive (Windows only)"},
		prompt.Suggest{Text: "--ip", Description: "IPv4 address (e.g., 172.30.100.104)"},
		prompt.Suggest{Text: "--ip6", Description: "IPv6 address (e.g., 2001:db8::33)"},
		prompt.Suggest{Text: "--ipc", Description: "IPC mode to use"},
		prompt.Suggest{Text: "--isolation", Description: "Container isolation technology"},
		prompt.Suggest{Text: "--kernel-memory", Description: "Kernel memory limit"},
		prompt.Suggest{Text: "--label", Description: "Set meta data on a container"},
		prompt.Suggest{Text: "--label-file", Description: "Read in a line delimited file of labels"},
		prompt.Suggest{Text: "--link", Description: "Add link to another container"},
		prompt.Suggest{Text: "--link-local-ip", Description: "Container IPv4/IPv6 link-local addresses"},
		prompt.Suggest{Text: "--log-driver", Description: "Logging driver for the container"},
		prompt.Suggest{Text: "--log-opt", Description: "Log driver options"},
		prompt.Suggest{Text: "--mac-address", Description: "Container MAC address (e.g., 92:d0:c6:0a:29:33)"},
		prompt.Suggest{Text: "--memory", Alias: "-m", Description: "Memory limit"},
		prompt.Suggest{Text: "--memory-reservation", Description: "Memory soft limit"},
		prompt.Suggest{Text: "--memory-swap", Description: "Swap limit equal to memory plus swap: ‘-1’ to enable unlimited swap"},
		prompt.Suggest{Text: "--memory-swappiness", Alias: "-1", Description: "Tune container memory swappiness (0 to 100)"},
		prompt.Suggest{Text: "--mount", Description: "Attach a filesystem mount to the container"},
		prompt.Suggest{Text: "--name", Description: "Assign a name to the container"},
		prompt.Suggest{Text: "--net", Description: "Connect a container to a network"},
		prompt.Suggest{Text: "--net-alias", Description: "Add network-scoped alias for the container"},
		prompt.Suggest{Text: "--network", Description: "Connect a container to a network"},
		prompt.Suggest{Text: "--network-alias", Description: "Add network-scoped alias for the container"},
		prompt.Suggest{Text: "--no-healthcheck", Description: "Disable any container-specified HEALTHCHECK"},
		prompt.Suggest{Text: "--oom-kill-disable", Description: "Disable OOM Killer"},
		prompt.Suggest{Text: "--oom-score-adj", Description: "Tune host's OOM preferences (-1000 to 1000)"},
		prompt.Suggest{Text: "--pid", Description: "PID namespace to use"},
		prompt.Suggest{Text: "--pids-limit", Description: "Tune container pids limit (set -1 for unlimited)"},
		prompt.Suggest{Text: "--platform", Description: "Set platform if server is multi-platform capable"},
		prompt.Suggest{Text: "--privileged", Description: "Give extended privileges to this container"},
		prompt.Suggest{Text: "--publish", Alias: "-p", Description: "Publish a container's port(s) to the host"},
		prompt.Suggest{Text: "--publish-all", Alias: "-P", Description: "Publish all exposed ports to random ports"},
		prompt.Suggest{Text: "--read-only", Description: "Mount the container's root filesystem as read only"},
		prompt.Suggest{Text: "--restart", Description: "Restart policy to apply when a container exits"},
		prompt.Suggest{Text: "--rm", Description: "Automatically remove the container when it exits"},
		prompt.Suggest{Text: "--runtime", Description: "Runtime to use for this container"},
		prompt.Suggest{Text: "--security-opt", Description: "Security Options"},
		prompt.Suggest{Text: "--shm-size", Description: "Size of /dev/shm"},
		prompt.Suggest{Text: "--stop-signal", Description: "Signal to stop a container"},
		prompt.Suggest{Text: "--stop-timeout", Description: "Timeout (in seconds) to stop a container"},
		prompt.Suggest{Text: "--storage-opt", Description: "Storage driver options for the container"},
		prompt.Suggest{Text: "--sysctl", Description: "Sysctl options"},
		prompt.Suggest{Text: "--tmpfs", Description: "Mount a tmpfs directory"},
		prompt.Suggest{Text: "--tty", Alias: "-t", Description: "Allocate a pseudo-TTY"},
		prompt.Suggest{Text: "--ulimit", Description: "Ulimit options"},
		prompt.Suggest{Text: "--user", Alias: "-u", Description: "Username or UID (format: &lt;name|uid&gt;[:&lt;group|gid&gt;])"},
		prompt.Suggest{Text: "--userns", Description: "User namespace to use"},
		prompt.Suggest{Text: "--uts", Description: "UTS namespace to use"},
		prompt.Suggest{Text: "--volume", Alias: "-v", Description: "Bind mount a volume"},
		prompt.Suggest{Text: "--volume-driver", Description: "Optional volume driver for the container"},
		prompt.Suggest{Text: "--volumes-from", Description: "Mount volumes from the specified container(s)"},
		prompt.Suggest{Text: "--workdir", Alias: "-w", Description: "Working directory inside the container"},
	},
	"compose": {
		prompt.Suggest{Text: "--ansi", Description: "Control when to print ANSI control characters (\"never\"|\"always\"|\"auto\")"},
		prompt.Suggest{Text: "--env-file", Description: "Specify an alternate environment file."},
		prompt.Suggest{Text: "--file", Alias: "-f", Description: "Compose configuration files"},
		prompt.Suggest{Text: "--profile", Description: "Specify a profile to enable"},
		prompt.Suggest{Text: "--project-directory", Description: "Specify an alternate working directory (default: the path of the Compose file)"},
		prompt.Suggest{Text: "--project-name", Alias: "-p", Description: "Project name"},
		prompt.Suggest{Text: "--workdir", Description: "DEPRECATED! USE prompt.--project-directory INSTEAD. Specify an alternate working directory (default: the path of the Compose file)"},
	},
	"events": {
		prompt.Suggest{Text: "--filter", Alias: "-f", Description: "Filter output based on conditions provided"},
		prompt.Suggest{Text: "--format", Description: "Format the output using the given Go template"},
		prompt.Suggest{Text: "--since", Description: "Show all events created since timestamp"},
		prompt.Suggest{Text: "--until", Description: "Stream events until this timestamp"},
	},
	"exec": {
		prompt.Suggest{Text: "--detach", Alias: "-d", Description: "Detached mode: run command in the background"},
		prompt.Suggest{Text: "--detach-keys", Description: "Override the key sequence for detaching a container"},
		prompt.Suggest{Text: "--env", Alias: "-e", Description: "Set environment variables"},
		prompt.Suggest{Text: "--env-file", Description: "Read in a file of environment variables"},
		prompt.Suggest{Text: "--interactive", Alias: "-i", Description: "Keep STDIN open even if not attached"},
		prompt.Suggest{Text: "--privileged", Description: "Give extended privileges to the command"},
		prompt.Suggest{Text: "--tty", Alias: "-t", Description: "Allocate a pseudo-TTY"},
		prompt.Suggest{Text: "--user", Alias: "-u", Description: "Username or UID (format: &lt;name|uid&gt;[:&lt;group|gid&gt;])"},
		prompt.Suggest{Text: "--workdir", Alias: "-w", Description: "Working directory inside the container"},
	},
	"export": {
		prompt.Suggest{Text: "--output", Alias: "-o", Description: "Write to a file, instead of STDOUT"},
	},
	"history": {
		prompt.Suggest{Text: "--format", Description: "Pretty-print images using a Go template"},
		prompt.Suggest{Text: "--human", Alias: "-H", Description: "Print sizes and dates in human readable format"},
		prompt.Suggest{Text: "--no-trunc", Description: "Don’t truncate output"},
		prompt.Suggest{Text: "--quiet", Alias: "-q", Description: "Only show numeric IDs"},
	},
	"images": {
		prompt.Suggest{Text: "--all", Alias: "-a", Description: "Show all images (default hides intermediate images)"},
		prompt.Suggest{Text: "--digests", Description: "Show digests"},
		prompt.Suggest{Text: "--filter", Alias: "-f", Description: "Filter output based on conditions provided"},
		prompt.Suggest{Text: "--format", Description: "Pretty-print images using a Go template"},
		prompt.Suggest{Text: "--no-trunc", Description: "Don’t truncate output"},
		prompt.Suggest{Text: "--quiet", Alias: "-q", Description: "Only show numeric IDs"},
	},
	"import": {
		prompt.Suggest{Text: "--change", Alias: "-c", Description: "Apply Dockerfile instruction to the created image"},
		prompt.Suggest{Text: "--message", Alias: "-m", Description: "Set commit message for imported image"},
		prompt.Suggest{Text: "--platform", Description: "Set platform if server is multi-platform capable"},
	},
	"info": {
		prompt.Suggest{Text: "--format", Alias: "-f", Description: "Format the output using the given Go template"},
	},
	"inspect": {
		prompt.Suggest{Text: "--format", Alias: "-f", Description: "Format the output using the given Go template"},
		prompt.Suggest{Text: "--size", Alias: "-s", Description: "Display total file sizes if the type is container"},
		prompt.Suggest{Text: "--type", Description: "Return JSON for specified type"},
	},
	"kill": {
		prompt.Suggest{Text: "--signal", Alias: "-s", Description: "Signal to send to the container"},
	},
	"load": {
		prompt.Suggest{Text: "--input", Alias: "-i", Description: "Read from tar archive file, instead of STDIN"},
		prompt.Suggest{Text: "--quiet", Alias: "-q", Description: "Suppress the load output"},
	},
	"login": {
		prompt.Suggest{Text: "--password", Alias: "-p", Description: "Password"},
		prompt.Suggest{Text: "--password-stdin", Description: "Take the password from stdin"},
		prompt.Suggest{Text: "--username", Alias: "-u", Description: "Username"},
	},
	"logs": {
		prompt.Suggest{Text: "--details", Description: "Show extra details provided to logs"},
		prompt.Suggest{Text: "--follow", Alias: "-f", Description: "Follow log output"},
		prompt.Suggest{Text: "--since", Description: "Show logs since timestamp (e.g. 2013-01-02T13:23:37) or relative (e.g. 42m for 42 minutes)"},
		prompt.Suggest{Text: "--tail", Alias: "-n", Description: "Number of lines to show from the end of the logs"},
		prompt.Suggest{Text: "--timestamps", Alias: "-t", Description: "Show timestamps"},
		prompt.Suggest{Text: "--until", Description: "Show logs before a timestamp (e.g. 2013-01-02T13:23:37Z) or relative (e.g. 42m for 42 minutes)"},
	},
	"ps": {
		prompt.Suggest{Text: "--all", Alias: "-a", Description: "Show all containers (default shows just running)"},
		prompt.Suggest{Text: "--filter", Alias: "-f", Description: "Filter output based on conditions provided"},
		prompt.Suggest{Text: "--format", Description: "Pretty-print containers using a Go template"},
		prompt.Suggest{Text: "--last", Alias: "-n", Description: "Show n last created containers (includes all states)"},
		prompt.Suggest{Text: "--latest", Alias: "-l", Description: "Show the latest created container (includes all states)"},
		prompt.Suggest{Text: "--no-trunc", Description: "Don’t truncate output"},
		prompt.Suggest{Text: "--quiet", Alias: "-q", Description: "Only display numeric IDs"},
		prompt.Suggest{Text: "--size", Alias: "-s", Description: "Display total file sizes"},
	},
	"pull": {
		prompt.Suggest{Text: "--all-tags", Alias: "-a", Description: "Download all tagged images in the repository"},
		prompt.Suggest{Text: "--disable-content-trust", Description: "Skip image verification"},
		prompt.Suggest{Text: "--platform", Description: "Set platform if server is multi-platform capable"},
		prompt.Suggest{Text: "--quiet", Alias: "-q", Description: "Suppress verbose output"},
	},
	"push": {
		prompt.Suggest{Text: "--all-tags", Alias: "-a", Description: "Push all tagged images in the repository"},
		prompt.Suggest{Text: "--disable-content-trust", Description: "Skip image signing"},
		prompt.Suggest{Text: "--quiet", Alias: "-q", Description: "Suppress verbose output"},
	},
	"restart": {
		prompt.Suggest{Text: "--time", Alias: "-t", Description: "Seconds to wait for stop before killing the container"},
	},
	"rm": {
		prompt.Suggest{Text: "--force", Alias: "-f", Description: "Force the removal of a running container (uses SIGKILL)"},
		prompt.Suggest{Text: "--link", Alias: "-l", Description: "Remove the specified link"},
		prompt.Suggest{Text: "--volumes", Alias: "-v", Description: "Remove the volumes associated with the container"},
	},
	"rmi": {
		prompt.Suggest{Text: "--force", Alias: "-f", Description: "Force removal of the image"},
		prompt.Suggest{Text: "--no-prune", Description: "Do not delete untagged parents"},
	},
	"run": {
		prompt.Suggest{Text: "--add-host", Description: "Add a custom host-to-IP mapping (host:ip)"},
		prompt.Suggest{Text: "--attach", Alias: "-a", Description: "Attach to STDIN, STDOUT or STDERR"},
		prompt.Suggest{Text: "--blkio-weight", Description: "Block IO (relative weight), between 10 and 1000, or 0 to disable (default 0)"},
		prompt.Suggest{Text: "--blkio-weight-device", Description: "Block IO weight (relative device weight)"},
		prompt.Suggest{Text: "--cap-add", Description: "Add Linux capabilities"},
		prompt.Suggest{Text: "--cap-drop", Description: "Drop Linux capabilities"},
		prompt.Suggest{Text: "--cgroupns", Description: "Cgroup namespace to use (host|private)"},
		prompt.Suggest{Text: "--cgroup-parent", Description: "Optional parent cgroup for the container"},
		prompt.Suggest{Text: "--cidfile", Description: "Write the container ID to the file"},
		prompt.Suggest{Text: "--cpu-count", Description: "CPU count (Windows only)"},
		prompt.Suggest{Text: "--cpu-percent", Description: "CPU percent (Windows only)"},
		prompt.Suggest{Text: "--cpu-period", Description: "Limit CPU CFS (Completely Fair Scheduler) period"},
		prompt.Suggest{Text: "--cpu-quota", Description: "Limit CPU CFS (Completely Fair Scheduler) quota"},
		prompt.Suggest{Text: "--cpu-rt-period", Description: "Limit CPU real-time period in microseconds"},
		prompt.Suggest{Text: "--cpu-rt-runtime", Description: "Limit CPU real-time runtime in microseconds"},
		prompt.Suggest{Text: "--cpu-shares", Alias: "-c", Description: "CPU shares (relative weight)"},
		prompt.Suggest{Text: "--cpus", Description: "Number of CPUs"},
		prompt.Suggest{Text: "--cpuset-cpus", Description: "CPUs in which to allow execution (0-3, 0,1)"},
		prompt.Suggest{Text: "--cpuset-mems", Description: "MEMs in which to allow execution (0-3, 0,1)"},
		prompt.Suggest{Text: "--detach", Alias: "-d", Description: "Run container in background and print container ID"},
		prompt.Suggest{Text: "--detach-keys", Description: "Override the key sequence for detaching a container"},
		prompt.Suggest{Text: "--device", Description: "Add a host device to the container"},
		prompt.Suggest{Text: "--device-cgroup-rule", Description: "Add a rule to the cgroup allowed devices list"},
		prompt.Suggest{Text: "--device-read-bps", Description: "Limit read rate (bytes per second) from a device"},
		prompt.Suggest{Text: "--device-read-iops", Description: "Limit read rate (IO per second) from a device"},
		prompt.Suggest{Text: "--device-write-bps", Description: "Limit write rate (bytes per second) to a device"},
		prompt.Suggest{Text: "--device-write-iops", Description: "Limit write rate (IO per second) to a device"},
		prompt.Suggest{Text: "--disable-content-trust", Description: "Skip image verification"},
		prompt.Suggest{Text: "--dns", Description: "Set custom DNS servers"},
		prompt.Suggest{Text: "--dns-opt", Description: "Set DNS options"},
		prompt.Suggest{Text: "--dns-option", Description: "Set DNS options"},
		prompt.Suggest{Text: "--dns-search", Description: "Set custom DNS search domains"},
		prompt.Suggest{Text: "--domainname", Description: "Container NIS domain name"},
		prompt.Suggest{Text: "--entrypoint", Description: "Overwrite the default ENTRYPOINT of the image"},
		prompt.Suggest{Text: "--env", Alias: "-e", Description: "Set environment variables"},
		prompt.Suggest{Text: "--env-file", Description: "Read in a file of environment variables"},
		prompt.Suggest{Text: "--expose", Description: "Expose a port or a range of ports"},
		prompt.Suggest{Text: "--gpus", Description: "GPU devices to add to the container ('all' to pass all GPUs)"},
		prompt.Suggest{Text: "--group-add", Description: "Add additional groups to join"},
		prompt.Suggest{Text: "--health-cmd", Description: "Command to run to check health"},
		prompt.Suggest{Text: "--health-interval", Description: "Time between running the check (ms|s|m|h) (default 0s)"},
		prompt.Suggest{Text: "--health-retries", Description: "Consecutive failures needed to report unhealthy"},
		prompt.Suggest{Text: "--health-start-period", Description: "Start period for the container to initialize before starting health-retries countdown (ms|s|m|h) (default 0s)"},
		prompt.Suggest{Text: "--health-timeout", Description: "Maximum time to allow one check to run (ms|s|m|h) (default 0s)"},
		prompt.Suggest{Text: "--help", Description: "Print usage"},
		prompt.Suggest{Text: "--hostname", Alias: "-h", Description: "Container host name"},
		prompt.Suggest{Text: "--init", Description: "Run an init inside the container that forwards signals and reaps processes"},
		prompt.Suggest{Text: "--interactive", Alias: "-i", Description: "Keep STDIN open even if not attached"},
		prompt.Suggest{Text: "--io-maxbandwidth", Description: "Maximum IO bandwidth limit for the system drive (Windows only)"},
		prompt.Suggest{Text: "--io-maxiops", Description: "Maximum IOps limit for the system drive (Windows only)"},
		prompt.Suggest{Text: "--ip", Description: "IPv4 address (e.g., 172.30.100.104)"},
		prompt.Suggest{Text: "--ip6", Description: "IPv6 address (e.g., 2001:db8::33)"},
		prompt.Suggest{Text: "--ipc", Description: "IPC mode to use"},
		prompt.Suggest{Text: "--isolation", Description: "Container isolation technology"},
		prompt.Suggest{Text: "--kernel-memory", Description: "Kernel memory limit"},
		prompt.Suggest{Text: "--label", Alias: "-l", Description: "Set meta data on a container"},
		prompt.Suggest{Text: "--label-file", Description: "Read in a line delimited file of labels"},
		prompt.Suggest{Text: "--link", Description: "Add link to another container"},
		prompt.Suggest{Text: "--link-local-ip", Description: "Container IPv4/IPv6 link-local addresses"},
		prompt.Suggest{Text: "--log-driver", Description: "Logging driver for the container"},
		prompt.Suggest{Text: "--log-opt", Description: "Log driver options"},
		prompt.Suggest{Text: "--mac-address", Description: "Container MAC address (e.g., 92:d0:c6:0a:29:33)"},
		prompt.Suggest{Text: "--memory", Alias: "-m", Description: "Memory limit"},
		prompt.Suggest{Text: "--memory-reservation", Description: "Memory soft limit"},
		prompt.Suggest{Text: "--memory-swap", Description: "Swap limit equal to memory plus swap: ‘-1’ to enable unlimited swap"},
		prompt.Suggest{Text: "--memory-swappiness", Description: "Tune container memory swappiness (0 to 100)"},
		prompt.Suggest{Text: "--mount", Description: "Attach a filesystem mount to the container"},
		prompt.Suggest{Text: "--name", Description: "Assign a name to the container"},
		prompt.Suggest{Text: "--net", Description: "Connect a container to a network"},
		prompt.Suggest{Text: "--net-alias", Description: "Add network-scoped alias for the container"},
		prompt.Suggest{Text: "--network", Description: "Connect a container to a network"},
		prompt.Suggest{Text: "--network-alias", Description: "Add network-scoped alias for the container"},
		prompt.Suggest{Text: "--no-healthcheck", Description: "Disable any container-specified HEALTHCHECK"},
		prompt.Suggest{Text: "--oom-kill-disable", Description: "Disable OOM Killer"},
		prompt.Suggest{Text: "--oom-score-adj", Description: "Tune host's OOM preferences (-1000 to 1000)"},
		prompt.Suggest{Text: "--pid", Description: "PID namespace to use"},
		prompt.Suggest{Text: "--pids-limit", Description: "Tune container pids limit (set -1 for unlimited)"},
		prompt.Suggest{Text: "--platform", Description: "Set platform if server is multi-platform capable"},
		prompt.Suggest{Text: "--privileged", Description: "Give extended privileges to this container"},
		prompt.Suggest{Text: "--publish", Alias: "-p", Description: "Publish a container's port(s) to the host"},
		prompt.Suggest{Text: "--publish-all", Alias: "-P", Description: "Publish all exposed ports to random ports"},
		prompt.Suggest{Text: "--read-only", Description: "Mount the container's root filesystem as read only"},
		prompt.Suggest{Text: "--restart", Description: "Restart policy to apply when a container exits"},
		prompt.Suggest{Text: "--rm", Description: "Automatically remove the container when it exits"},
		prompt.Suggest{Text: "--runtime", Description: "Runtime to use for this container"},
		prompt.Suggest{Text: "--security-opt", Description: "Security Options"},
		prompt.Suggest{Text: "--shm-size", Description: "Size of /dev/shm"},
		prompt.Suggest{Text: "--sig-proxy", Description: "Proxy received signals to the process"},
		prompt.Suggest{Text: "--stop-signal", Description: "Signal to stop a container"},
		prompt.Suggest{Text: "--stop-timeout", Description: "Timeout (in seconds) to stop a container"},
		prompt.Suggest{Text: "--storage-opt", Description: "Storage driver options for the container"},
		prompt.Suggest{Text: "--sysctl", Description: "Sysctl options"},
		prompt.Suggest{Text: "--tmpfs", Description: "Mount a tmpfs directory"},
		prompt.Suggest{Text: "--tty", Alias: "-t", Description: "Allocate a pseudo-TTY"},
		prompt.Suggest{Text: "--ulimit", Description: "Ulimit options"},
		prompt.Suggest{Text: "--user", Alias: "-u", Description: "Username or UID (format: &lt;name|uid&gt;[:&lt;group|gid&gt;])"},
		prompt.Suggest{Text: "--userns", Description: "User namespace to use"},
		prompt.Suggest{Text: "--uts", Description: "UTS namespace to use"},
		prompt.Suggest{Text: "--volume", Alias: "-v", Description: "Bind mount a volume"},
		prompt.Suggest{Text: "--volume-driver", Description: "Optional volume driver for the container"},
		prompt.Suggest{Text: "--volumes-from", Description: "Mount volumes from the specified container(s)"},
		prompt.Suggest{Text: "--workdir", Alias: "-w", Description: "Working directory inside the container"},
	},
	"save": {
		prompt.Suggest{Text: "--output", Alias: "-o", Description: "Write to a file, instead of STDOUT"},
	},
	"search": {
		prompt.Suggest{Text: "--filter", Alias: "-f", Description: "Filter output based on conditions provided"},
		prompt.Suggest{Text: "--format", Description: "Pretty-print search using a Go template"},
		prompt.Suggest{Text: "--limit", Description: "Max number of search results"},
		prompt.Suggest{Text: "--no-trunc", Description: "Don’t truncate output"},
	},
	"stack": {
		prompt.Suggest{Text: "--kubeconfig", Description: ""},
		prompt.Suggest{Text: "--orchestrator", Description: "Orchestrator to use (swarm|kubernetes|all)"},
	},
	"start": {
		prompt.Suggest{Text: "--attach", Alias: "-a", Description: "Attach STDOUT/STDERR and forward signals"},
		prompt.Suggest{Text: "--checkpoint", Description: "Restore from this checkpoint"},
		prompt.Suggest{Text: "--checkpoint-dir", Description: "Use a custom checkpoint storage directory"},
		prompt.Suggest{Text: "--detach-keys", Description: "Override the key sequence for detaching a container"},
		prompt.Suggest{Text: "--interactive", Alias: "-i", Description: "Attach container's STDIN"},
	},
	"stats": {
		prompt.Suggest{Text: "--all", Alias: "-a", Description: "Show all containers (default shows just running)"},
		prompt.Suggest{Text: "--format", Description: "Pretty-print images using a Go template"},
		prompt.Suggest{Text: "--no-stream", Description: "Disable streaming stats and only pull the first result"},
		prompt.Suggest{Text: "--no-trunc", Description: "Do not truncate output"},
	},
	"stop": {
		prompt.Suggest{Text: "--time", Alias: "-t", Description: "Seconds to wait for stop before killing it"},
	},
	"update": {
		prompt.Suggest{Text: "--blkio-weight", Description: "Block IO (relative weight), between 10 and 1000, or 0 to disable (default 0)"},
		prompt.Suggest{Text: "--cpu-period", Description: "Limit CPU CFS (Completely Fair Scheduler) period"},
		prompt.Suggest{Text: "--cpu-quota", Description: "Limit CPU CFS (Completely Fair Scheduler) quota"},
		prompt.Suggest{Text: "--cpu-rt-period", Description: "Limit the CPU real-time period in microseconds"},
		prompt.Suggest{Text: "--cpu-rt-runtime", Description: "Limit the CPU real-time runtime in microseconds"},
		prompt.Suggest{Text: "--cpu-shares", Alias: "-c", Description: "CPU shares (relative weight)"},
		prompt.Suggest{Text: "--cpus", Description: "Number of CPUs"},
		prompt.Suggest{Text: "--cpuset-cpus", Description: "CPUs in which to allow execution (0-3, 0,1)"},
		prompt.Suggest{Text: "--cpuset-mems", Description: "MEMs in which to allow execution (0-3, 0,1)"},
		prompt.Suggest{Text: "--kernel-memory", Description: "Kernel memory limit"},
		prompt.Suggest{Text: "--memory", Alias: "-m", Description: "Memory limit"},
		prompt.Suggest{Text: "--memory-reservation", Description: "Memory soft limit"},
		prompt.Suggest{Text: "--memory-swap", Description: "Swap limit equal to memory plus swap: ‘-1’ to enable unlimited swap"},
		prompt.Suggest{Text: "--pids-limit", Description: "Tune container pids limit (set -1 for unlimited)"},
		prompt.Suggest{Text: "--restart", Description: "Restart policy to apply when a container exits"},
	},
	"version": {
		prompt.Suggest{Text: "--format", Alias: "-f", Description: "Format the output using the given Go template"},
		prompt.Suggest{Text: "--kubeconfig", Description: "Kubernetes config file"},
	},
	"app bundle": {
		prompt.Suggest{Text: "--output", Alias: "-o", Description: "Output file (- for stdout)"},
	},
	"app init": {
		prompt.Suggest{Text: "--compose-file", Description: "Compose file to use as application base (optional)"},
		prompt.Suggest{Text: "--description", Description: "Human readable description of your application (optional)"},
		prompt.Suggest{Text: "--maintainer", Description: "Name and email address of person responsible for the application (name:email) (optional)"},
		prompt.Suggest{Text: "--single-file", Description: "Create a single-file Docker Application definition"},
	},
	"app inspect": {
		prompt.Suggest{Text: "--insecure-registries", Description: "Use HTTP instead of HTTPS when pulling from/pushing to those registries"},
		prompt.Suggest{Text: "--parameters-file", Description: "Override parameters file"},
		prompt.Suggest{Text: "--pull", Description: "Pull the bundle"},
		prompt.Suggest{Text: "--set", Alias: "-s", Description: "Override parameter value"},
	},
	"app install": {
		prompt.Suggest{Text: "--credential-set", Description: "Use a YAML file containing a credential set or a credential set present in the credential store"},
		prompt.Suggest{Text: "--insecure-registries", Description: "Use HTTP instead of HTTPS when pulling from/pushing to those registries"},
		prompt.Suggest{Text: "--kubernetes-namespace", Description: "Kubernetes namespace to install into"},
		prompt.Suggest{Text: "--name", Description: "Installation name (defaults to application name)"},
		prompt.Suggest{Text: "--orchestrator", Description: "Orchestrator to install on (swarm, kubernetes)"},
		prompt.Suggest{Text: "--parameters-file", Description: "Override parameters file"},
		prompt.Suggest{Text: "--pull", Description: "Pull the bundle"},
		prompt.Suggest{Text: "--set", Alias: "-s", Description: "Override parameter value"},
		prompt.Suggest{Text: "--target-context", Description: "Context on which the application is installed (default: <current-context>)"},
		prompt.Suggest{Text: "--with-registry-auth", Description: "Sends registry auth"},
	},
	"app list": {
		prompt.Suggest{Text: "--target-context", Description: "List installations on this context"},
	},
	"app pull": {
		prompt.Suggest{Text: "--insecure-registries", Description: "Use HTTP instead of HTTPS when pulling from/pushing to those registries"},
	},
	"app push": {
		prompt.Suggest{Text: "--insecure-registries", Description: "Use HTTP instead of HTTPS when pulling from/pushing to those registries"},
		prompt.Suggest{Text: "--platform", Description: "For multi-arch service images, only push the specified platforms"},
		prompt.Suggest{Text: "--tag", Alias: "-t", Description: "Target registry reference (default: <name>:<version> from metadata)"},
	},
	"app render": {
		prompt.Suggest{Text: "--formatter", Description: "Configure the output format (yaml|json)"},
		prompt.Suggest{Text: "--insecure-registries", Description: "Use HTTP instead of HTTPS when pulling from/pushing to those registries"},
		prompt.Suggest{Text: "--output", Alias: "-o", Description: "Output file"},
		prompt.Suggest{Text: "--parameters-file", Description: "Override parameters file"},
		prompt.Suggest{Text: "--pull", Description: "Pull the bundle"},
		prompt.Suggest{Text: "--set", Alias: "-s", Description: "Override parameter value"},
	},
	"app status": {
		prompt.Suggest{Text: "--credential-set", Description: "Use a YAML file containing a credential set or a credential set present in the credential store"},
		prompt.Suggest{Text: "--target-context", Description: "Context on which the application is installed (default: <current-context>)"},
		prompt.Suggest{Text: "--with-registry-auth", Description: "Sends registry auth"},
	},
	"app uninstall": {
		prompt.Suggest{Text: "--credential-set", Description: "Use a YAML file containing a credential set or a credential set present in the credential store"},
		prompt.Suggest{Text: "--force", Description: "Force removal of installation"},
		prompt.Suggest{Text: "--target-context", Description: "Context on which the application is installed (default: <current-context>)"},
		prompt.Suggest{Text: "--with-registry-auth", Description: "Sends registry auth"},
	},
	"app upgrade": {
		prompt.Suggest{Text: "--app-name", Description: "Override the installation with another Application Package"},
		prompt.Suggest{Text: "--credential-set", Description: "Use a YAML file containing a credential set or a credential set present in the credential store"},
		prompt.Suggest{Text: "--insecure-registries", Description: "Use HTTP instead of HTTPS when pulling from/pushing to those registries"},
		prompt.Suggest{Text: "--parameters-file", Description: "Override parameters file"},
		prompt.Suggest{Text: "--pull", Description: "Pull the bundle"},
		prompt.Suggest{Text: "--set", Alias: "-s", Description: "Override parameter value"},
		prompt.Suggest{Text: "--target-context", Description: "Context on which the application is installed (default: <current-context>)"},
		prompt.Suggest{Text: "--with-registry-auth", Description: "Sends registry auth"},
	},
	"app validate": {
		prompt.Suggest{Text: "--parameters-file", Description: "Override parameters file"},
		prompt.Suggest{Text: "--set", Alias: "-s", Description: "Override parameter value"},
	},
	"builder build": {
		prompt.Suggest{Text: "--add-host", Description: "Add a custom host-to-IP mapping (host:ip)"},
		prompt.Suggest{Text: "--build-arg", Description: "Set build-time variables"},
		prompt.Suggest{Text: "--cache-from", Description: "Images to consider as cache sources"},
		prompt.Suggest{Text: "--cgroup-parent", Description: "Optional parent cgroup for the container"},
		prompt.Suggest{Text: "--compress", Description: "Compress the build context using gzip"},
		prompt.Suggest{Text: "--cpu-period", Description: "Limit the CPU CFS (Completely Fair Scheduler) period"},
		prompt.Suggest{Text: "--cpu-quota", Description: "Limit the CPU CFS (Completely Fair Scheduler) quota"},
		prompt.Suggest{Text: "--cpu-shares", Alias: "-c", Description: "CPU shares (relative weight)"},
		prompt.Suggest{Text: "--cpuset-cpus", Description: "CPUs in which to allow execution (0-3, 0,1)"},
		prompt.Suggest{Text: "--cpuset-mems", Description: "MEMs in which to allow execution (0-3, 0,1)"},
		prompt.Suggest{Text: "--disable-content-trust	true	Skip image verification"},
		prompt.Suggest{Text: "--file", Alias: "-f", Description: "Name of the Dockerfile (Default is 'PATH/Dockerfile')"},
		prompt.Suggest{Text: "--force-rm", Description: "Always remove intermediate containers"},
		prompt.Suggest{Text: "--iidfile", Description: "Write the image ID to the file"},
		prompt.Suggest{Text: "--isolation", Description: "Container isolation technology"},
		prompt.Suggest{Text: "--label", Description: "Set metadata for an image"},
		prompt.Suggest{Text: "--memory", Alias: "-m", Description: "Memory limit"},
		prompt.Suggest{Text: "--memory-swap", Description: "Swap limit equal to memory plus swap: '-1' to enable unlimited swap"},
		prompt.Suggest{Text: "--network", Description: "Set the networking mode for the RUN instructions during build"},
		prompt.Suggest{Text: "--no-cache", Description: "Do not use cache when building the image"},
		prompt.Suggest{Text: "--output", Alias: "-o", Description: "Output destination (format: type=local,dest=path)"},
		prompt.Suggest{Text: "--platform", Description: "Set platform if server is multi-platform capable"},
		prompt.Suggest{Text: "--progress", Description: "Set type of progress output (auto, plain, tty). Use plain to show container output"},
		prompt.Suggest{Text: "--pull", Description: "Always attempt to pull a newer version of the image"},
		prompt.Suggest{Text: "--quiet", Alias: "-q", Description: "Suppress the build output and print image ID on success"},
		prompt.Suggest{Text: "--rm", Description: "Remove intermediate containers after a successful build"},
		prompt.Suggest{Text: "--secret", Description: "Secret file to expose to the build (only if BuildKit enabled): id=mysecret,src=/local/secret"},
		prompt.Suggest{Text: "--security-opt", Description: "Security options"},
		prompt.Suggest{Text: "--shm-size", Description: "Size of /dev/shm"},
		prompt.Suggest{Text: "--squash", Description: "Squash newly built layers into a single new layer"},
		prompt.Suggest{Text: "--ssh", Description: "SSH agent socket or keys to expose to the build (only if BuildKit enabled) (format: default|<id>[=<socket>|<key>[,<key>]])"},
		prompt.Suggest{Text: "--stream", Description: "Stream attaches to server to negotiate build context"},
		prompt.Suggest{Text: "--tag", Alias: "-t", Description: "Name and optionally a tag in the 'name:tag' format"},
		prompt.Suggest{Text: "--target", Description: "Set the target build stage to build."},
		prompt.Suggest{Text: "--ulimit", Description: "Ulimit options"},
	},
	"builder prune": {
		prompt.Suggest{Text: "--all", Alias: "-a", Description: "Remove all unused build cache, not just dangling ones"},
		prompt.Suggest{Text: "--filter", Description: "Provide filter values (e.g. 'until=24h')"},
		prompt.Suggest{Text: "--force", Alias: "-f", Description: "Do not prompt for confirmation"},
		prompt.Suggest{Text: "--keep-storage", Description: "Amount of disk space to keep for cache"},
	},
	"buildx bake": {
		prompt.Suggest{Text: "--file", Alias: "-f", Description: "Build definition file"},
		prompt.Suggest{Text: "--load", Description: "Shorthand for prompt.--set=*.output=type=docker"},
		prompt.Suggest{Text: "--no-cache", Description: "Do not use cache when building the image"},
		prompt.Suggest{Text: "--print", Description: "Print the options without building"},
		prompt.Suggest{Text: "--progress", Description: "Set type of progress output (auto, plain, tty). Use plain to show container output"},
		prompt.Suggest{Text: "--pull", Description: "Always attempt to pull a newer version of the image"},
		prompt.Suggest{Text: "--push", Description: "Shorthand for prompt.--set=*.output=type=registry"},
		prompt.Suggest{Text: "--set", Description: "Override target value (eg: targetpattern.key=value)"},
		prompt.Suggest{Text: "--builder", Description: "Override the configured builder instance"},
	},
	"buildx build": {
		prompt.Suggest{Text: "--add-host", Description: "Add a custom host-to-IP mapping (host:ip)"},
		prompt.Suggest{Text: "--allow", Description: "Allow extra privileged entitlement, e.g. network.host, security.insecure"},
		prompt.Suggest{Text: "--build-arg", Description: "Set build-time variables"},
		prompt.Suggest{Text: "--cache-from", Description: "External cache sources (eg. user/app:cache, type=local,src=path/to/dir)"},
		prompt.Suggest{Text: "--cache-to", Description: "Cache export destinations (eg. user/app:cache, type=local,dest=path/to/dir)"},
		prompt.Suggest{Text: "--cgroup-parent", Description: "Optional parent cgroup for the container"},
		prompt.Suggest{Text: "--compress", Description: "Compress the build context using gzip"},
		prompt.Suggest{Text: "--cpu-period", Description: "Limit the CPU CFS (Completely Fair Scheduler) period"},
		prompt.Suggest{Text: "--cpu-quota", Description: "Limit the CPU CFS (Completely Fair Scheduler) quota"},
		prompt.Suggest{Text: "--cpu-shares", Alias: "-c", Description: "CPU shares (relative weight)"},
		prompt.Suggest{Text: "--cpuset-cpus", Description: "CPUs in which to allow execution (0-3, 0,1)"},
		prompt.Suggest{Text: "--cpuset-mems", Description: "MEMs in which to allow execution (0-3, 0,1)"},
		prompt.Suggest{Text: "--file", Alias: "-f", Description: "Name of the Dockerfile (Default is 'PATH/Dockerfile')"},
		prompt.Suggest{Text: "--force-rm", Description: "Always remove intermediate containers"},
		prompt.Suggest{Text: "--iidfile", Description: "Write the image ID to the file"},
		prompt.Suggest{Text: "--isolation", Description: "Container isolation technology"},
		prompt.Suggest{Text: "--label", Description: "Set metadata for an image"},
		prompt.Suggest{Text: "--load", Description: "Shorthand for prompt.--output=type=docker"},
		prompt.Suggest{Text: "--memory", Alias: "-m", Description: "Memory limit"},
		prompt.Suggest{Text: "--memory-swap", Description: "Swap limit equal to memory plus swap: '-1' to enable unlimited swap"},
		prompt.Suggest{Text: "--network", Description: "Set the networking mode for the RUN instructions during build"},
		prompt.Suggest{Text: "--no-cache", Description: "Do not use cache when building the image"},
		prompt.Suggest{Text: "--output", Alias: "-o", Description: "Output destination (format: type=local,dest=path)"},
		prompt.Suggest{Text: "--platform", Description: "Set target platform for build"},
		prompt.Suggest{Text: "--progress", Description: "Set type of progress output (auto, plain, tty). Use plain to show container output"},
		prompt.Suggest{Text: "--pull", Description: "Always attempt to pull a newer version of the image"},
		prompt.Suggest{Text: "--push", Description: "Shorthand for prompt.--output=type=registry"},
		prompt.Suggest{Text: "--quiet", Alias: "-q", Description: "Suppress the build output and print image ID on success"},
		prompt.Suggest{Text: "--rm", Description: "Remove intermediate containers after a successful build"},
		prompt.Suggest{Text: "--secret", Description: "Secret file to expose to the build: id=mysecret,src=/local/secret"},
		prompt.Suggest{Text: "--security-opt", Description: "Security options"},
		prompt.Suggest{Text: "--shm-size", Description: "Size of /dev/shm"},
		prompt.Suggest{Text: "--squash", Description: "Squash newly built layers into a single new layer"},
		prompt.Suggest{Text: "--ssh", Description: "SSH agent socket or keys to expose to the build (format: default|<id>[=<socket>|<key>[,<key>]])"},
		prompt.Suggest{Text: "--tag", Alias: "-t", Description: "Name and optionally a tag in the 'name:tag' format"},
		prompt.Suggest{Text: "--target", Description: "Set the target build stage to build."},
		prompt.Suggest{Text: "--ulimit", Description: "Ulimit options"},
		prompt.Suggest{Text: "--builder", Description: "Override the configured builder instance"},
	},
	"buildx create": {
		prompt.Suggest{Text: "--append", Description: "Append a node to builder instead of changing it"},
		prompt.Suggest{Text: "--buildkitd-flags", Description: "Flags for buildkitd daemon"},
		prompt.Suggest{Text: "--config", Description: "BuildKit config file"},
		prompt.Suggest{Text: "--driver", Description: "Driver to use (available: [])"},
		prompt.Suggest{Text: "--driver-opt", Description: "Options for the driver"},
		prompt.Suggest{Text: "--leave", Description: "Remove a node from builder instead of changing it"},
		prompt.Suggest{Text: "--name", Description: "Builder instance name"},
		prompt.Suggest{Text: "--node", Description: "Create/modify node with given name"},
		prompt.Suggest{Text: "--platform", Description: "Fixed platforms for current node"},
		prompt.Suggest{Text: "--use", Description: "Set the current builder instance"},
		prompt.Suggest{Text: "--builder", Description: "Override the configured builder instance"},
	},
	"buildx du": {
		prompt.Suggest{Text: "--filter", Description: "Provide filter values"},
		prompt.Suggest{Text: "--verbose", Description: "Provide a more verbose output"},
		prompt.Suggest{Text: "--builder", Description: "Override the configured builder instance"},
	},
	"buildx inspect": {
		prompt.Suggest{Text: "--bootstrap", Description: "Ensure builder has booted before inspecting"},
		prompt.Suggest{Text: "--builder", Description: "Override the configured builder instance"},
	},
	"buildx prune": {
		prompt.Suggest{Text: "--all", Alias: "-a", Description: "Remove all unused images, not just dangling ones"},
		prompt.Suggest{Text: "--filter", Description: "Provide filter values (e.g. 'until=24h')"},
		prompt.Suggest{Text: "--force", Alias: "-f", Description: "Do not prompt for confirmation"},
		prompt.Suggest{Text: "--keep-storage", Description: "Amount of disk space to keep for cache"},
		prompt.Suggest{Text: "--verbose", Description: "Provide a more verbose output"},
		prompt.Suggest{Text: "--builder", Description: "Override the configured builder instance"},
	},
	"buildx use": {
		prompt.Suggest{Text: "--default", Description: "Set builder as default for current context"},
		prompt.Suggest{Text: "--global", Description: "Builder persists context changes"},
		prompt.Suggest{Text: "--builder", Description: "Override the configured builder instance"},
	},
	"checkpoint create": {
		prompt.Suggest{Text: "--checkpoint-dir", Description: "Use a custom checkpoint storage directory"},
		prompt.Suggest{Text: "--leave-running", Description: "Leave the container running after checkpoint"},
	},
	"checkpoint ls": {
		prompt.Suggest{Text: "--checkpoint-dir", Description: "Use a custom checkpoint storage directory"},
	},
	"checkpoint rm": {
		prompt.Suggest{Text: "--checkpoint-dir", Description: "Use a custom checkpoint storage directory"},
	},
	"compose build": {
		prompt.Suggest{Text: "--build-arg", Description: "Set build-time variables for services."},
		prompt.Suggest{Text: "--progress", Description: "Set type of progress output (\"auto\", \"plain\", \"tty\")"},
		prompt.Suggest{Text: "--pull", Description: "Always attempt to pull a newer version of the image."},
		prompt.Suggest{Text: "--quiet", Alias: "-q", Description: "Don't print anything to STDOUT"},
	},
	"compose convert": {
		prompt.Suggest{Text: "--format", Description: "Format the output. Values: [yaml | json]"},
		prompt.Suggest{Text: "--quiet", Alias: "-q", Description: "Don't print anything to STDOUT"},
		prompt.Suggest{Text: "--resolve-image-digests", Description: "Pin image tags to digests."},
	},
	"compose create": {
		prompt.Suggest{Text: "--build", Description: "Build images before starting containers."},
		prompt.Suggest{Text: "--force-recreate", Description: "Recreate containers even if their configuration and image haven't changed."},
		prompt.Suggest{Text: "--no-build", Description: "Don't build an image, even if it's missing."},
		prompt.Suggest{Text: "--no-recreate", Description: "If containers already exist, don't recreate them. Incompatible with --force-recreate."},
	},
	"compose down": {
		prompt.Suggest{Text: "--remove-orphans", Description: "Remove containers for services not defined in the Compose file."},
		prompt.Suggest{Text: "--rmi", Description: "Remove images used by services. \"local\" remove only images that don't have a custom tag (\"local\"|\"all\")"},
		prompt.Suggest{Text: "--timeout", Alias: "-t", Description: "Specify a shutdown timeout in seconds"},
		prompt.Suggest{Text: "--volumes", Alias: "-v", Description: "Remove named volumes declared in the volumes section of the Compose file and anonymous volumes attached to containers."},
	},
	"compose events": {
		prompt.Suggest{Text: "--json", Description: "Output events as a stream of json objects"},
	},
	"compose exec": {
		prompt.Suggest{Text: "--no-TTY", Alias: "-T", Description: "Disable pseudo-tty allocation. By default docker compose exec allocates a TTY."},
		prompt.Suggest{Text: "--detach", Alias: "-d", Description: "Detached mode: Run command in the background."},
		prompt.Suggest{Text: "--env", Alias: "-e", Description: "Set environment variables"},
		prompt.Suggest{Text: "--index", Description: "index of the container if there are multiple instances of a service [default: 1]."},
		prompt.Suggest{Text: "--privileged", Description: "Give extended privileges to the process."},
		prompt.Suggest{Text: "--user", Alias: "-u", Description: "Run the command as this user."},
		prompt.Suggest{Text: "--workdir", Alias: "-w", Description: "Path to workdir directory for this command."},
	},
	"compose images": {
		prompt.Suggest{Text: "--quiet", Alias: "-q", Description: "Only display IDs"},
	},
	"compose kill": {
		prompt.Suggest{Text: "--signal", Alias: "-s", Description: "SIGNAL to send to the container."},
	},
	"compose logs": {
		prompt.Suggest{Text: "--follow", Alias: "-f", Description: "Follow log output."},
		prompt.Suggest{Text: "--no-color", Description: "Produce monochrome output."},
		prompt.Suggest{Text: "--no-log-prefix", Description: "Don't print prefix in logs."},
		prompt.Suggest{Text: "--timestamps", Alias: "-t", Description: "Show timestamps."},
	},
	"compose ls": {
		prompt.Suggest{Text: "--filter", Description: "Filter output based on conditions provided"},
		prompt.Suggest{Text: "--format", Description: "Format the output. Values: [pretty | json]."},
		prompt.Suggest{Text: "--quiet", Alias: "-q", Description: "Only display IDs"},
	},
	"compose ps": {
		prompt.Suggest{Text: "--all", Alias: "-a", Description: "Show all stopped containers (including those created by the run command)"},
		prompt.Suggest{Text: "--services", Description: "Display services"},
		prompt.Suggest{Text: "--format", Description: "Format the output. Values: [pretty | json]."},
		prompt.Suggest{Text: "--quiet", Alias: "-q", Description: "Only display IDs"},
	},
	"compose pull": {
		prompt.Suggest{Text: "--include-deps", Description: "Also pull services declared as dependencies"},
		prompt.Suggest{Text: "--quiet", Alias: "-q", Description: "Pull without printing progress information"},
	},
	"compose push": {
		prompt.Suggest{Text: "--ignore-push-failures", Description: "Push what it can and ignores images with push failures"},
	},
	"compose rm": {
		prompt.Suggest{Text: "--force", Alias: "-f", Description: "Don't ask to confirm removal"},
		prompt.Suggest{Text: "--stop", Alias: "-s", Description: "Stop the containers, if required, before removing"},
		prompt.Suggest{Text: "--volumes", Alias: "-v", Description: "Remove any anonymous volumes attached to containers"},
	},
	"compose run": {
		prompt.Suggest{Text: "--detach", Alias: "-d", Description: "Run container in background and print container ID"},
		prompt.Suggest{Text: "--entrypoint", Description: "Override the entrypoint of the image"},
		prompt.Suggest{Text: "--env", Alias: "-e", Description: "Set environment variables"},
		prompt.Suggest{Text: "--labels", Alias: "-l", Description: "Add or override a label"},
		prompt.Suggest{Text: "--name", Description: "Assign a name to the container"},
		prompt.Suggest{Text: "--no-TTY", Alias: "-T", Description: "Disable pseudo-tty allocation. By default docker compose run allocates a TTY"},
		prompt.Suggest{Text: "--no-deps", Description: "Don't start linked services."},
		prompt.Suggest{Text: "--publish", Alias: "-p", Description: "Publish a container's port(s) to the host."},
		prompt.Suggest{Text: "--rm", Description: "Automatically remove the container when it exits"},
		prompt.Suggest{Text: "--service-ports", Description: "Run command with the service's ports enabled and mapped to the host."},
		prompt.Suggest{Text: "--use-aliases", Description: "Use the service's network useAliases in the network(s) the container connects to."},
		prompt.Suggest{Text: "--user", Alias: "-u", Description: "Run as specified username or uid"},
		prompt.Suggest{Text: "--volumes", Alias: "-v", Description: "Bind mount a volume."},
		prompt.Suggest{Text: "--workdir", Alias: "-w", Description: "Working directory inside the container"},
	},
	"compose stop": {
		prompt.Suggest{Text: "--timeout", Alias: "-t", Description: "Specify a shutdown timeout in seconds"},
	},
	"compose up": {
		prompt.Suggest{Text: "--abort-on-container-exit", Description: "Stops all containers if any container was stopped. Incompatible with -d"},
		prompt.Suggest{Text: "--always-recreate-deps", Description: "Recreate dependent containers. Incompatible with prompt.--no-recreate."},
		prompt.Suggest{Text: "--attach-dependencies", Description: "Attach to dependent containers."},
		prompt.Suggest{Text: "--build", Description: "Build images before starting containers."},
		prompt.Suggest{Text: "--detach", Alias: "-d", Description: "Detached mode: Run containers in the background"},
		prompt.Suggest{Text: "--environment", Alias: "-e", Description: "Environment variables"},
		prompt.Suggest{Text: "--exit-code-from", Description: "Return the exit code of the selected service container. Implies prompt.--abort-on-container-exit"},
		prompt.Suggest{Text: "--force-recreate", Description: "Recreate containers even if their configuration and image haven't changed."},
		prompt.Suggest{Text: "--no-build", Description: "Don't build an image, even if it's missing."},
		prompt.Suggest{Text: "--no-color", Description: "Produce monochrome output."},
		prompt.Suggest{Text: "--no-deps", Description: "Don't start linked services."},
		prompt.Suggest{Text: "--no-log-prefix", Description: "Don't print prefix in logs."},
		prompt.Suggest{Text: "--no-recreate", Description: "If containers already exist, don't recreate them. Incompatible with prompt.--force-recreate."},
		prompt.Suggest{Text: "--no-start", Description: "Don't start the services after creating them."},
		prompt.Suggest{Text: "--remove-orphans", Description: "Remove containers for services not defined in the Compose file."},
		prompt.Suggest{Text: "--renew-anon-volumes", Alias: "-V", Description: "Recreate anonymous volumes instead of retrieving data from the previous containers."},
		prompt.Suggest{Text: "--scale", Description: "Scale SERVICE to NUM instances. Overrides the scale setting in the Compose file if present."},
		prompt.Suggest{Text: "--timeout", Alias: "-t", Description: "Use this timeout in seconds for container shutdown when attached or when containers are already running."},
	},
	"config create": {
		prompt.Suggest{Text: "--label", Description: "Config labels"},
		prompt.Suggest{Text: "--template-driver", Description: "Template driver"},
	},
	"config inspect": {
		prompt.Suggest{Text: "--format", Alias: "-f", Description: "Format the output using the given Go template"},
		prompt.Suggest{Text: "--pretty", Description: "Print the information in a human friendly format"},
	},
	"config ls": {
		prompt.Suggest{Text: "--filter", Alias: "-f", Description: "Filter output based on conditions provided"},
		prompt.Suggest{Text: "--format", Alias: "-f", Description: "Format the output using the given Go template"},
		prompt.Suggest{Text: "--quiet", Alias: "-q", Description: "Only display IDs"},
	},
	"container attach": {
		prompt.Suggest{Text: "--detach-keys", Description: "Override the key sequence for detaching a container"},
		prompt.Suggest{Text: "--no-stdin", Description: "Do not attach STDIN"},
		prompt.Suggest{Text: "--sig-proxy", Description: "Proxy all received signals to the process"},
	},
	"container commit": {
		prompt.Suggest{Text: "--author", Alias: "-a", Description: "Author (e.g., \"John Hannibal Smith <hannibal@a-team.com>\")"},
		prompt.Suggest{Text: "--change", Alias: "-c", Description: "Apply Dockerfile instruction to the created image"},
		prompt.Suggest{Text: "--message", Alias: "-m", Description: "Commit message"},
		prompt.Suggest{Text: "--pause", Alias: "-p", Description: "Pause container during commit"},
	},
	"container cp": {
		prompt.Suggest{Text: "--archive", Alias: "-a", Description: "Archive mode (copy all uid/gid information)"},
		prompt.Suggest{Text: "--follow-link", Alias: "-L", Description: "Always follow symbol link in SRC_PATH"},
	},
	"container create": {
		prompt.Suggest{Text: "--add-host", Description: "Add a custom host-to-IP mapping (host:ip)"},
		prompt.Suggest{Text: "--attach", Alias: "-a", Description: "Attach to STDIN, STDOUT or STDERR"},
		prompt.Suggest{Text: "--blkio-weight", Description: "Block IO (relative weight), between 10 and 1000, or 0 to disable (default 0)"},
		prompt.Suggest{Text: "--blkio-weight-device", Description: "Block IO weight (relative device weight)"},
		prompt.Suggest{Text: "--cap-add", Description: "Add Linux capabilities"},
		prompt.Suggest{Text: "--cap-drop", Description: "Drop Linux capabilities"},
		prompt.Suggest{Text: "--cgroup-parent", Description: "Optional parent cgroup for the container"},
		prompt.Suggest{Text: "--cgroupns", Description: "Cgroup namespace to use (host|private) 'host'"},
		prompt.Suggest{Text: "--cidfile", Description: "Write the container ID to the file"},
		prompt.Suggest{Text: "--cpu-count", Description: "CPU count (Windows only)"},
		prompt.Suggest{Text: "--cpu-percent", Description: "CPU percent (Windows only)"},
		prompt.Suggest{Text: "--cpu-period", Description: "Limit CPU CFS (Completely Fair Scheduler) period"},
		prompt.Suggest{Text: "--cpu-quota", Description: "Limit CPU CFS (Completely Fair Scheduler) quota"},
		prompt.Suggest{Text: "--cpu-rt-period", Description: "Limit CPU real-time period in microseconds"},
		prompt.Suggest{Text: "--cpu-rt-runtime", Description: "Limit CPU real-time runtime in microseconds"},
		prompt.Suggest{Text: "--cpu-shares", Alias: "-c", Description: "CPU shares (relative weight)"},
		prompt.Suggest{Text: "--cpus", Description: "Number of CPUs"},
		prompt.Suggest{Text: "--cpuset-cpus", Description: "CPUs in which to allow execution (0-3, 0,1)"},
		prompt.Suggest{Text: "--cpuset-mems", Description: "MEMs in which to allow execution (0-3, 0,1)"},
		prompt.Suggest{Text: "--device", Description: "Add a host device to the container"},
		prompt.Suggest{Text: "--device-cgroup-rule", Description: "Add a rule to the cgroup allowed devices list"},
		prompt.Suggest{Text: "--device-read-bps", Description: "Limit read rate (bytes per second) from a device"},
		prompt.Suggest{Text: "--device-read-iops", Description: "Limit read rate (IO per second) from a device"},
		prompt.Suggest{Text: "--device-write-bps", Description: "Limit write rate (bytes per second) to a device"},
		prompt.Suggest{Text: "--device-write-iops", Description: "Limit write rate (IO per second) to a device"},
		prompt.Suggest{Text: "--disable-content-trust", Description: "Skip image verification"},
		prompt.Suggest{Text: "--dns", Description: "Set custom DNS servers"},
		prompt.Suggest{Text: "--dns-opt", Description: "Set DNS options"},
		prompt.Suggest{Text: "--dns-option", Description: "Set DNS options"},
		prompt.Suggest{Text: "--dns-search", Description: "Set custom DNS search domains"},
		prompt.Suggest{Text: "--domainname", Description: "Container NIS domain name"},
		prompt.Suggest{Text: "--entrypoint", Description: "Overwrite the default ENTRYPOINT of the image"},
		prompt.Suggest{Text: "--env", Alias: "-e", Description: "Set environment variables"},
		prompt.Suggest{Text: "--env-file", Description: "Read in a file of environment variables"},
		prompt.Suggest{Text: "--expose", Description: "Expose a port or a range of ports"},
		prompt.Suggest{Text: "--gpus", Description: "GPU devices to add to the container ('all' to pass all GPUs)"},
		prompt.Suggest{Text: "--group-add", Description: "Add additional groups to join"},
		prompt.Suggest{Text: "--health-cmd", Description: "Command to run to check health"},
		prompt.Suggest{Text: "--health-interval", Description: "Time between running the check (ms|s|m|h) (default 0s)"},
		prompt.Suggest{Text: "--health-retries", Description: "Consecutive failures needed to report unhealthy"},
		prompt.Suggest{Text: "--health-start-period", Description: "Start period for the container to initialize before starting health-retries countdown (ms|s|m|h) (default 0s)"},
		prompt.Suggest{Text: "--health-timeout", Description: "Maximum time to allow one check to run (ms|s|m|h) (default 0s)"},
		prompt.Suggest{Text: "--help", Description: "Print usage"},
		prompt.Suggest{Text: "--hostname", Alias: " -h", Description: "Container host name"},
		prompt.Suggest{Text: "--init", Description: "Run an init inside the container that forwards signals and reaps processes"},
		prompt.Suggest{Text: "--interactive", Alias: "-i", Description: "Keep STDIN open even if not attached"},
		prompt.Suggest{Text: "--io-maxbandwidth", Description: "Maximum IO bandwidth limit for the system drive (Windows only)"},
		prompt.Suggest{Text: "--io-maxiops", Description: "Maximum IOps limit for the system drive (Windows only)"},
		prompt.Suggest{Text: "--ip", Description: "IPv4 address (e.g., 172.30.100.104)"},
		prompt.Suggest{Text: "--ip6", Description: "IPv6 address (e.g., 2001:db8::33)"},
		prompt.Suggest{Text: "--ipc", Description: "IPC mode to use"},
		prompt.Suggest{Text: "--isolation", Description: "Container isolation technology"},
		prompt.Suggest{Text: "--kernel-memory", Description: "Kernel memory limit"},
		prompt.Suggest{Text: "--label", Alias: "-l", Description: "Set meta data on a container"},
		prompt.Suggest{Text: "--label-file", Description: "Read in a line delimited file of labels"},
		prompt.Suggest{Text: "--link", Description: "Add link to another container"},
		prompt.Suggest{Text: "--link-local-ip", Description: "Container IPv4/IPv6 link-local addresses"},
		prompt.Suggest{Text: "--log-driver", Description: "Logging driver for the container"},
		prompt.Suggest{Text: "--log-opt", Description: "Log driver options"},
		prompt.Suggest{Text: "--mac-address", Description: "Container MAC address (e.g., 92:d0:c6:0a:29:33)"},
		prompt.Suggest{Text: "--memory", Alias: "-m", Description: "Memory limit"},
		prompt.Suggest{Text: "--memory-reservation", Description: "Memory soft limit"},
		prompt.Suggest{Text: "--memory-swap", Description: "Swap limit equal to memory plus swap: '-1' to enable unlimited swap"},
		prompt.Suggest{Text: "--memory-swappiness", Description: "Tune container memory swappiness (0 to 100)"},
		prompt.Suggest{Text: "--mount", Description: "Attach a filesystem mount to the container"},
		prompt.Suggest{Text: "--name", Description: "Assign a name to the container"},
		prompt.Suggest{Text: "--net", Description: "Connect a container to a network"},
		prompt.Suggest{Text: "--net-alias", Description: "Add network-scoped alias for the container"},
		prompt.Suggest{Text: "--network", Description: "Connect a container to a network"},
		prompt.Suggest{Text: "--network-alias", Description: "Add network-scoped alias for the container"},
		prompt.Suggest{Text: "--no-healthcheck", Description: "Disable any container-specified HEALTHCHECK"},
		prompt.Suggest{Text: "--oom-kill-disable", Description: "Disable OOM Killer"},
		prompt.Suggest{Text: "--oom-score-adj", Description: "Tune host's OOM preferences (-1000 to 1000)"},
		prompt.Suggest{Text: "--pid", Description: "PID namespace to use"},
		prompt.Suggest{Text: "--pids-limit", Description: "Tune container pids limit (set -1 for unlimited)"},
		prompt.Suggest{Text: "--platform", Description: "Set platform if server is multi-platform capable"},
		prompt.Suggest{Text: "--privileged", Description: "Give extended privileges to this container"},
		prompt.Suggest{Text: "--publish", Alias: "-p", Description: "Publish a container's port(s) to the host"},
		prompt.Suggest{Text: "--publish-all", Alias: "-P", Description: "Publish all exposed ports to random ports"},
		prompt.Suggest{Text: "--pull", Description: "missing	Pull image before creating ('always'|'missing'|'never')"},
		prompt.Suggest{Text: "--read-only", Description: "Mount the container's root filesystem as read only"},
		prompt.Suggest{Text: "--restart", Description: "Restart policy to apply when a container exits"},
		prompt.Suggest{Text: "--rm", Description: "Automatically remove the container when it exits"},
		prompt.Suggest{Text: "--runtime", Description: "Runtime to use for this container"},
		prompt.Suggest{Text: "--security-opt", Description: "Security Options"},
		prompt.Suggest{Text: "--shm-size", Description: "Size of /dev/shm"},
		prompt.Suggest{Text: "--stop-signal", Description: "SIGTERM	Signal to stop a container"},
		prompt.Suggest{Text: "--stop-timeout", Description: "Timeout (in seconds) to stop a container"},
		prompt.Suggest{Text: "--storage-opt", Description: "Storage driver options for the container"},
		prompt.Suggest{Text: "--sysctl", Description: "Sysctl options"},
		prompt.Suggest{Text: "--tmpfs", Description: "Mount a tmpfs directory"},
		prompt.Suggest{Text: "--tty", Alias: "-t", Description: "Allocate a pseudo-TTY"},
		prompt.Suggest{Text: "--ulimit", Description: "Ulimit options"},
		prompt.Suggest{Text: "--user", Alias: "-u", Description: "Username or UID (format: <name|uid>[:<group|gid>])"},
		prompt.Suggest{Text: "--userns", Description: "User namespace to use"},
		prompt.Suggest{Text: "--uts", Description: "UTS namespace to use"},
		prompt.Suggest{Text: "--volume", Alias: "-v", Description: "Bind mount a volume"},
		prompt.Suggest{Text: "--volume-driver", Description: "Optional volume driver for the container"},
		prompt.Suggest{Text: "--volumes-from", Description: "Mount volumes from the specified container(s)"},
		prompt.Suggest{Text: "--workdir", Alias: "-w", Description: "Working directory inside the container"},
	},
	"container exec": {
		prompt.Suggest{Text: "--detach", Alias: "-d", Description: "Detached mode: run command in the background"},
		prompt.Suggest{Text: "--detach-keys", Description: "Override the key sequence for detaching a container"},
		prompt.Suggest{Text: "--env", Alias: "-e", Description: "Set environment variables"},
		prompt.Suggest{Text: "--env-file", Description: "Read in a file of environment variables"},
		prompt.Suggest{Text: "--interactive", Alias: "-i", Description: "Keep STDIN open even if not attached"},
		prompt.Suggest{Text: "--privileged", Description: "Give extended privileges to the command"},
		prompt.Suggest{Text: "--tty", Alias: "-t", Description: "Allocate a pseudo-TTY"},
		prompt.Suggest{Text: "--user", Alias: "-u", Description: "Username or UID (format: <name|uid>[:<group|gid>])"},
		prompt.Suggest{Text: "--workdir", Alias: "-w", Description: "Working directory inside the container"},
	},
	"container export": {
		prompt.Suggest{Text: "--output", Alias: "-o", Description: "Write to a file, instead of STDOUT"},
	},
	"container inspect": {
		prompt.Suggest{Text: "--format", Alias: "-f", Description: "Format the output using the given Go template"},
		prompt.Suggest{Text: "--size", Alias: "-s", Description: "Display total file sizes"},
	},
	"container kill": {
		prompt.Suggest{Text: "--signal", Alias: "-s", Description: "Signal to send to the container"},
	},
	"container logs": {
		prompt.Suggest{Text: "--details", Description: "Show extra details provided to logs"},
		prompt.Suggest{Text: "--follow", Alias: "-f", Description: "Follow log output"},
		prompt.Suggest{Text: "--since", Description: "Show logs since timestamp (e.g. 2013-01-02T13:23:37Z) or relative (e.g. 42m for 42 minutes)"},
		prompt.Suggest{Text: "--tail", Alias: "-n", Description: "Number of lines to show from the end of the logs"},
		prompt.Suggest{Text: "--timestamps", Alias: "-t", Description: "Show timestamps"},
		prompt.Suggest{Text: "--until", Description: "Show logs before a timestamp (e.g. 2013-01-02T13:23:37Z) or relative (e.g. 42m for 42 minutes)"},
	},
	"container ls": {
		prompt.Suggest{Text: "--all", Alias: "-a", Description: "Show all containers (default shows just running)"},
		prompt.Suggest{Text: "--filter", Alias: "-f", Description: "Filter output based on conditions provided"},
		prompt.Suggest{Text: "--format", Description: "Pretty-print containers using a Go template"},
		prompt.Suggest{Text: "--last", Alias: "-n", Description: "Show n last created containers (includes all states)"},
		prompt.Suggest{Text: "--latest", Alias: "-l", Description: "Show the latest created container (includes all states)"},
		prompt.Suggest{Text: "--no-trunc", Description: "Don't truncate output"},
		prompt.Suggest{Text: "--quiet", Alias: "-q", Description: "Only display container IDs"},
		prompt.Suggest{Text: "--size", Alias: "-s", Description: "Display total file sizes"},
	},
	"container prune": {
		prompt.Suggest{Text: "--filter", Description: "Provide filter values (e.g. 'until=<timestamp>')"},
		prompt.Suggest{Text: "--force", Alias: "-f", Description: "Do not prompt for confirmation"},
	},
	"container restart": {
		prompt.Suggest{Text: "--time", Alias: "-t", Description: "Seconds to wait for stop before killing the container"},
	},
	"container rm": {
		prompt.Suggest{Text: "--force", Alias: "-f", Description: "Force the removal of a running container (uses SIGKILL)"},
		prompt.Suggest{Text: "--link", Alias: "-l", Description: "Remove the specified link"},
		prompt.Suggest{Text: "--volumes", Alias: "-v", Description: "Remove anonymous volumes associated with the container"},
	},
	"container run": {
		prompt.Suggest{Text: "--add-host", Description: "Add a custom host-to-IP mapping (host:ip)"},
		prompt.Suggest{Text: "--attach", Alias: "-a", Description: "Attach to STDIN, STDOUT or STDERR"},
		prompt.Suggest{Text: "--blkio-weight", Description: "Block IO (relative weight), between 10 and 1000, or 0 to disable (default 0)"},
		prompt.Suggest{Text: "--blkio-weight-device", Description: "Block IO weight (relative device weight)"},
		prompt.Suggest{Text: "--cap-add", Description: "Add Linux capabilities"},
		prompt.Suggest{Text: "--cap-drop", Description: "Drop Linux capabilities"},
		prompt.Suggest{Text: "--cgroup-parent", Description: "Optional parent cgroup for the container"},
		prompt.Suggest{Text: "--cgroupns", Description: "Cgroup namespace to use (host|private) 'host': Run the container in the Docker host's cgroup namespace 'private': Run the container in its own private cgroup namespace '': Use the cgroup namespace as configured by the default-cgroupns-mode option on the daemon (default)"},
		prompt.Suggest{Text: "--cidfile", Description: "Write the container ID to the file"},
		prompt.Suggest{Text: "--cpu-count", Description: "CPU count (Windows only)"},
		prompt.Suggest{Text: "--cpu-percent", Description: "CPU percent (Windows only)"},
		prompt.Suggest{Text: "--cpu-period", Description: "Limit CPU CFS (Completely Fair Scheduler) period"},
		prompt.Suggest{Text: "--cpu-quota", Description: "Limit CPU CFS (Completely Fair Scheduler) quota"},
		prompt.Suggest{Text: "--cpu-rt-period", Description: "Limit CPU real-time period in microseconds"},
		prompt.Suggest{Text: "--cpu-rt-runtime", Description: "Limit CPU real-time runtime in microseconds"},
		prompt.Suggest{Text: "--cpu-shares", Alias: "-c", Description: "CPU shares (relative weight)"},
		prompt.Suggest{Text: "--cpus", Description: "Number of CPUs"},
		prompt.Suggest{Text: "--cpuset-cpus", Description: "CPUs in which to allow execution (0-3, 0,1)"},
		prompt.Suggest{Text: "--cpuset-mems", Description: "MEMs in which to allow execution (0-3, 0,1)"},
		prompt.Suggest{Text: "--detach", Alias: "-d", Description: "Run container in background and print container ID"},
		prompt.Suggest{Text: "--detach-keys", Description: "Override the key sequence for detaching a container"},
		prompt.Suggest{Text: "--device", Description: "Add a host device to the container"},
		prompt.Suggest{Text: "--device-cgroup-rule", Description: "Add a rule to the cgroup allowed devices list"},
		prompt.Suggest{Text: "--device-read-bps", Description: "Limit read rate (bytes per second) from a device"},
		prompt.Suggest{Text: "--device-read-iops", Description: "Limit read rate (IO per second) from a device"},
		prompt.Suggest{Text: "--device-write-bps", Description: "Limit write rate (bytes per second) to a device"},
		prompt.Suggest{Text: "--device-write-iops", Description: "Limit write rate (IO per second) to a device"},
		prompt.Suggest{Text: "--disable-content-trust	true	Skip image verification"},
		prompt.Suggest{Text: "--dns", Description: "Set custom DNS servers"},
		prompt.Suggest{Text: "--dns-opt", Description: "Set DNS options"},
		prompt.Suggest{Text: "--dns-option", Description: "Set DNS options"},
		prompt.Suggest{Text: "--dns-search", Description: "Set custom DNS search domains"},
		prompt.Suggest{Text: "--domainname", Description: "Container NIS domain name"},
		prompt.Suggest{Text: "--entrypoint", Description: "Overwrite the default ENTRYPOINT of the image"},
		prompt.Suggest{Text: "--env", Alias: "-e", Description: "Set environment variables"},
		prompt.Suggest{Text: "--env-file", Description: "Read in a file of environment variables"},
		prompt.Suggest{Text: "--expose", Description: "Expose a port or a range of ports"},
		prompt.Suggest{Text: "--gpus", Description: "GPU devices to add to the container ('all' to pass all GPUs)"},
		prompt.Suggest{Text: "--group-add", Description: "Add additional groups to join"},
		prompt.Suggest{Text: "--health-cmd", Description: "Command to run to check health"},
		prompt.Suggest{Text: "--health-interval", Description: "Time between running the check (ms|s|m|h) (default 0s)"},
		prompt.Suggest{Text: "--health-retries", Description: "Consecutive failures needed to report unhealthy"},
		prompt.Suggest{Text: "--health-start-period", Description: "Start period for the container to initialize before starting health-retries countdown (ms|s|m|h) (default 0s)"},
		prompt.Suggest{Text: "--health-timeout", Description: "Maximum time to allow one check to run (ms|s|m|h) (default 0s)"},
		prompt.Suggest{Text: "--help", Description: "Print usage"},
		prompt.Suggest{Text: "--hostname", Alias: "-h", Description: "Container host name"},
		prompt.Suggest{Text: "--init", Description: "Run an init inside the container that forwards signals and reaps processes"},
		prompt.Suggest{Text: "--interactive", Alias: "-i", Description: "Keep STDIN open even if not attached"},
		prompt.Suggest{Text: "--io-maxbandwidth", Description: "Maximum IO bandwidth limit for the system drive (Windows only)"},
		prompt.Suggest{Text: "--io-maxiops", Description: "Maximum IOps limit for the system drive (Windows only)"},
		prompt.Suggest{Text: "--ip", Description: "IPv4 address (e.g., 172.30.100.104)"},
		prompt.Suggest{Text: "--ip6", Description: "IPv6 address (e.g., 2001:db8::33)"},
		prompt.Suggest{Text: "--ipc", Description: "IPC mode to use"},
		prompt.Suggest{Text: "--isolation", Description: "Container isolation technology"},
		prompt.Suggest{Text: "--kernel-memory", Description: "Kernel memory limit"},
		prompt.Suggest{Text: "--label", Alias: "-l", Description: "Set meta data on a container"},
		prompt.Suggest{Text: "--label-file", Description: "Read in a line delimited file of labels"},
		prompt.Suggest{Text: "--link", Description: "Add link to another container"},
		prompt.Suggest{Text: "--link-local-ip", Description: "Container IPv4/IPv6 link-local addresses"},
		prompt.Suggest{Text: "--log-driver", Description: "Logging driver for the container"},
		prompt.Suggest{Text: "--log-opt", Description: "Log driver options"},
		prompt.Suggest{Text: "--mac-address", Description: "Container MAC address (e.g., 92:d0:c6:0a:29:33)"},
		prompt.Suggest{Text: "--memory", Alias: "-m", Description: "Memory limit"},
		prompt.Suggest{Text: "--memory-reservation", Description: "Memory soft limit"},
		prompt.Suggest{Text: "--memory-swap", Description: "Swap limit equal to memory plus swap: '-1' to enable unlimited swap"},
		prompt.Suggest{Text: "--memory-swappiness", Description: "Tune container memory swappiness (0 to 100)"},
		prompt.Suggest{Text: "--mount", Description: "Attach a filesystem mount to the container"},
		prompt.Suggest{Text: "--name", Description: "Assign a name to the container"},
		prompt.Suggest{Text: "--net", Description: "Connect a container to a network"},
		prompt.Suggest{Text: "--net-alias", Description: "Add network-scoped alias for the container"},
		prompt.Suggest{Text: "--network", Description: "Connect a container to a network"},
		prompt.Suggest{Text: "--network-alias", Description: "Add network-scoped alias for the container"},
		prompt.Suggest{Text: "--no-healthcheck", Description: "Disable any container-specified HEALTHCHECK"},
		prompt.Suggest{Text: "--oom-kill-disable", Description: "Disable OOM Killer"},
		prompt.Suggest{Text: "--oom-score-adj", Description: "Tune host's OOM preferences (-1000 to 1000)"},
		prompt.Suggest{Text: "--pid", Description: "PID namespace to use"},
		prompt.Suggest{Text: "--pids-limit", Description: "Tune container pids limit (set -1 for unlimited)"},
		prompt.Suggest{Text: "--platform", Description: "Set platform if server is multi-platform capable"},
		prompt.Suggest{Text: "--privileged", Description: "Give extended privileges to this container"},
		prompt.Suggest{Text: "--publish", Alias: "-p", Description: "Publish a container's port(s) to the host"},
		prompt.Suggest{Text: "--publish-all", Alias: "-P", Description: "Publish all exposed ports to random ports"},
		prompt.Suggest{Text: "--pull", Description: "Pull image before running ('always'|'missing'|'never')"},
		prompt.Suggest{Text: "--read-only", Description: "Mount the container's root filesystem as read only"},
		prompt.Suggest{Text: "--restart", Description: "Restart policy to apply when a container exits"},
		prompt.Suggest{Text: "--rm", Description: "Automatically remove the container when it exits"},
		prompt.Suggest{Text: "--runtime", Description: "Runtime to use for this container"},
		prompt.Suggest{Text: "--security-opt", Description: "Security Options"},
		prompt.Suggest{Text: "--shm-size", Description: "Size of /dev/shm"},
		prompt.Suggest{Text: "--sig-proxy", Description: "Proxy received signals to the process"},
		prompt.Suggest{Text: "--stop-signal", Description: "Signal to stop a container"},
		prompt.Suggest{Text: "--stop-timeout", Description: "Timeout (in seconds) to stop a container"},
		prompt.Suggest{Text: "--storage-opt", Description: "Storage driver options for the container"},
		prompt.Suggest{Text: "--sysctl", Description: "Sysctl options"},
		prompt.Suggest{Text: "--tmpfs", Description: "Mount a tmpfs directory"},
		prompt.Suggest{Text: "--tty", Alias: "-t", Description: "Allocate a pseudo-TTY"},
		prompt.Suggest{Text: "--ulimit", Description: "Ulimit options"},
		prompt.Suggest{Text: "--user", Alias: "-u", Description: "Username or UID (format: <name|uid>[:<group|gid>])"},
		prompt.Suggest{Text: "--userns", Description: "User namespace to use"},
		prompt.Suggest{Text: "--uts", Description: "UTS namespace to use"},
		prompt.Suggest{Text: "--volume", Alias: "-v", Description: "Bind mount a volume"},
		prompt.Suggest{Text: "--volume-driver", Description: "Optional volume driver for the container"},
		prompt.Suggest{Text: "--volumes-from", Description: "Mount volumes from the specified container(s)"},
		prompt.Suggest{Text: "--workdir", Alias: "-w", Description: "Working directory inside the container"},
	},
	"container start": {
		prompt.Suggest{Text: "--attach", Alias: "-a", Description: "Attach STDOUT/STDERR and forward signals"},
		prompt.Suggest{Text: "--checkpoint", Description: "Restore from this checkpoint"},
		prompt.Suggest{Text: "--checkpoint-dir", Description: "Use a custom checkpoint storage directory"},
		prompt.Suggest{Text: "--detach-keys", Description: "Override the key sequence for detaching a container"},
		prompt.Suggest{Text: "--interactive", Alias: "-i", Description: "Attach container's STDIN"},
	},
	"container stats": {
		prompt.Suggest{Text: "--all", Alias: "-a", Description: "Show all containers (default shows just running)"},
		prompt.Suggest{Text: "--format", Description: "Pretty-print images using a Go template"},
		prompt.Suggest{Text: "--no-stream", Description: "Disable streaming stats and only pull the first result"},
		prompt.Suggest{Text: "--no-trunc", Description: "Do not truncate output"},
	},
	"container stop": {
		prompt.Suggest{Text: "--time", Alias: "-t", Description: "Seconds to wait for stop before killing it"},
	},
	"container update": {
		prompt.Suggest{Text: "--blkio-weight", Description: "Block IO (relative weight), between 10 and 1000, or 0 to disable (default 0)"},
		prompt.Suggest{Text: "--cpu-period", Description: "Limit CPU CFS (Completely Fair Scheduler) period"},
		prompt.Suggest{Text: "--cpu-quota", Description: "Limit CPU CFS (Completely Fair Scheduler) quota"},
		prompt.Suggest{Text: "--cpu-rt-period", Description: "Limit the CPU real-time period in microseconds"},
		prompt.Suggest{Text: "--cpu-rt-runtime", Description: "Limit the CPU real-time runtime in microseconds"},
		prompt.Suggest{Text: "--cpu-shares", Alias: "-c", Description: "CPU shares (relative weight)"},
		prompt.Suggest{Text: "--cpus", Description: "Number of CPUs"},
		prompt.Suggest{Text: "--cpuset-cpus", Description: "CPUs in which to allow execution (0-3, 0,1)"},
		prompt.Suggest{Text: "--cpuset-mems", Description: "MEMs in which to allow execution (0-3, 0,1)"},
		prompt.Suggest{Text: "--kernel-memory", Description: "Kernel memory limit"},
		prompt.Suggest{Text: "--memory", Alias: "-m", Description: "Memory limit"},
		prompt.Suggest{Text: "--memory-reservation", Description: "Memory soft limit"},
		prompt.Suggest{Text: "--memory-swap", Description: "Swap limit equal to memory plus swap: '-1' to enable unlimited swap"},
		prompt.Suggest{Text: "--pids-limit", Description: "Tune container pids limit (set -1 for unlimited)"},
		prompt.Suggest{Text: "--restart", Description: "Restart policy to apply when a container exits"},
	},
	"context create": {
		prompt.Suggest{Text: "--default-stack-orchestrator", Description: "Default orchestrator for stack operations to use with this context (swarm|kubernetes|all)"},
		prompt.Suggest{Text: "--description", Description: "Description of the context"},
		prompt.Suggest{Text: "--docker", Description: "set the docker endpoint"},
		prompt.Suggest{Text: "--from", Description: "create context from a named context"},
		prompt.Suggest{Text: "--kubernetes", Description: "set the kubernetes endpoint"},
	},
	"context export": {
		prompt.Suggest{Text: "--kubeconfig", Description: "Export as a kubeconfig file"},
	},
	"context inspect": {
		prompt.Suggest{Text: "--format", Alias: "-f", Description: "Format the output using the given Go template"},
	},
	"context ls": {
		prompt.Suggest{Text: "--format", Description: "Format the output using the given Go template"},
		prompt.Suggest{Text: "--quiet", Alias: "-q", Description: "Only show context names"},
	},
	"context rm": {
		prompt.Suggest{Text: "--force", Alias: "-f", Description: "Force the removal of a context in use"},
	},
	"context update": {
		prompt.Suggest{Text: "--default-stack-orchestrator", Description: "Default orchestrator for stack operations to use with this context (swarm|kubernetes|all)"},
		prompt.Suggest{Text: "--description", Description: "Description of the context"},
		prompt.Suggest{Text: "--docker", Description: "set the docker endpoint"},
		prompt.Suggest{Text: "--kubernetes", Description: "set the kubernetes endpoint"},
	},
	"image build": {
		prompt.Suggest{Text: "--add-host", Description: "Add a custom host-to-IP mapping (host:ip)"},
		prompt.Suggest{Text: "--build-arg", Description: "Set build-time variables"},
		prompt.Suggest{Text: "--cache-from", Description: "Images to consider as cache sources"},
		prompt.Suggest{Text: "--cgroup-parent", Description: "Optional parent cgroup for the container"},
		prompt.Suggest{Text: "--compress", Description: "Compress the build context using gzip"},
		prompt.Suggest{Text: "--cpu-period", Description: "Limit the CPU CFS (Completely Fair Scheduler) period"},
		prompt.Suggest{Text: "--cpu-quota", Description: "Limit the CPU CFS (Completely Fair Scheduler) quota"},
		prompt.Suggest{Text: "--cpu-shares", Alias: "-c", Description: "CPU shares (relative weight)"},
		prompt.Suggest{Text: "--cpuset-cpus", Description: "CPUs in which to allow execution (0-3, 0,1)"},
		prompt.Suggest{Text: "--cpuset-mems", Description: "MEMs in which to allow execution (0-3, 0,1)"},
		prompt.Suggest{Text: "--disable-content-trust	true	Skip image verification"},
		prompt.Suggest{Text: "--file", Alias: "-f", Description: "Name of the Dockerfile (Default is 'PATH/Dockerfile')"},
		prompt.Suggest{Text: "--force-rm", Description: "Always remove intermediate containers"},
		prompt.Suggest{Text: "--iidfile", Description: "Write the image ID to the file"},
		prompt.Suggest{Text: "--isolation", Description: "Container isolation technology"},
		prompt.Suggest{Text: "--label", Description: "Set metadata for an image"},
		prompt.Suggest{Text: "--memory", Alias: "-m", Description: "Memory limit"},
		prompt.Suggest{Text: "--memory-swap", Description: "Swap limit equal to memory plus swap: '-1' to enable unlimited swap"},
		prompt.Suggest{Text: "--network", Description: "Set the networking mode for the RUN instructions during build"},
		prompt.Suggest{Text: "--no-cache", Description: "Do not use cache when building the image"},
		prompt.Suggest{Text: "--output", Alias: "-o", Description: "Output destination (format: type=local,dest=path)"},
		prompt.Suggest{Text: "--platform", Description: "Set platform if server is multi-platform capable"},
		prompt.Suggest{Text: "--progress", Description: "Set type of progress output (auto, plain, tty). Use plain to show container output"},
		prompt.Suggest{Text: "--pull", Description: "Always attempt to pull a newer version of the image"},
		prompt.Suggest{Text: "--quiet", Alias: "-q", Description: "Suppress the build output and print image ID on success"},
		prompt.Suggest{Text: "--rm", Description: "Remove intermediate containers after a successful build"},
		prompt.Suggest{Text: "--secret", Description: "Secret file to expose to the build (only if BuildKit enabled): id=mysecret,src=/local/secret"},
		prompt.Suggest{Text: "--security-opt", Description: "Security options"},
		prompt.Suggest{Text: "--shm-size", Description: "Size of /dev/shm"},
		prompt.Suggest{Text: "--squash", Description: "Squash newly built layers into a single new layer"},
		prompt.Suggest{Text: "--ssh", Description: "SSH agent socket or keys to expose to the build (only if BuildKit enabled) (format: default|<id>[=<socket>|<key>[,<key>]])"},
		prompt.Suggest{Text: "--stream", Description: "Stream attaches to server to negotiate build context"},
		prompt.Suggest{Text: "--tag", Alias: "-t", Description: "Name and optionally a tag in the 'name:tag' format"},
		prompt.Suggest{Text: "--target", Description: "Set the target build stage to build."},
		prompt.Suggest{Text: "--ulimit", Description: "Ulimit options"},
	},
	"image history": {
		prompt.Suggest{Text: "--format", Description: "Pretty-print images using a Go template"},
		prompt.Suggest{Text: "--human", Alias: "-H", Description: "Print sizes and dates in human readable format"},
		prompt.Suggest{Text: "--no-trunc", Description: "Don't truncate output"},
		prompt.Suggest{Text: "--quiet", Alias: "-q", Description: "Only show image IDs"},
	},
	"image import": {
		prompt.Suggest{Text: "--change", Alias: "-c", Description: "Apply Dockerfile instruction to the created image"},
		prompt.Suggest{Text: "--message", Alias: "-m", Description: "Set commit message for imported image"},
		prompt.Suggest{Text: "--platform", Description: "Set platform if server is multi-platform capable"},
	},
	"image inspect": {
		prompt.Suggest{Text: "--format", Alias: "-f", Description: "Pretty-print images using a Go template"},
	},
	"image load": {
		prompt.Suggest{Text: "--input", Alias: "-i", Description: "Read from tar archive file, instead of STDIN"},
		prompt.Suggest{Text: "--quiet", Alias: "-q", Description: "Suppress the load output"},
	},
	"image ls": {
		prompt.Suggest{Text: "--all", Alias: "-a", Description: "Show all images (default hides intermediate images)"},
		prompt.Suggest{Text: "--digests", Description: "Show digests"},
		prompt.Suggest{Text: "--filter", Alias: "-f", Description: "Filter output based on conditions provided"},
		prompt.Suggest{Text: "--format", Description: "Pretty-print images using a Go template"},
		prompt.Suggest{Text: "--no-trunc", Description: "Don't truncate output"},
		prompt.Suggest{Text: "--quiet", Alias: "-q", Description: "Only show image IDs"},
	},
	"image prune": {
		prompt.Suggest{Text: "--all", Alias: "-a", Description: "Remove all unused images, not just dangling ones"},
		prompt.Suggest{Text: "--filter", Description: "Provide filter values (e.g. 'until=<timestamp>')"},
		prompt.Suggest{Text: "--force", Alias: "-f", Description: "Do not prompt for confirmation"},
	},
	"image pull": {
		prompt.Suggest{Text: "--all-tags", Alias: "-a", Description: "Download all tagged images in the repository"},
		prompt.Suggest{Text: "--disable-content-trust", Description: "Skip image verification"},
		prompt.Suggest{Text: "--platform", Description: "Set platform if server is multi-platform capable"},
		prompt.Suggest{Text: "--quiet", Alias: "-q", Description: "Suppress verbose output"},
	},
	"image push": {
		prompt.Suggest{Text: "--all-tags", Alias: "-a", Description: "Push all tagged images in the repository"},
		prompt.Suggest{Text: "--disable-content-trust", Description: "Skip image signing"},
		prompt.Suggest{Text: "--quiet", Alias: "-q", Description: "Suppress verbose output"},
	},
	"image rm": {
		prompt.Suggest{Text: "--force", Alias: "-f", Description: "Do not prompt for confirmation"},
		prompt.Suggest{Text: "--no-prune", Description: "Do not delete untagged parents"},
	},
	"image save": {
		prompt.Suggest{Text: "--output", Alias: "-o", Description: "Write to a file, instead of STDOUT"},
	},
	"manifest annotate": {
		prompt.Suggest{Text: "--arch", Description: "Set architecture"},
		prompt.Suggest{Text: "--os", Description: "Set operating system"},
		prompt.Suggest{Text: "--os-features", Description: "Set operating system feature"},
		prompt.Suggest{Text: "--os-version", Description: "Set operating system version"},
		prompt.Suggest{Text: "--variant", Description: "Set architecture variant"},
	},
	"manifest create": {
		prompt.Suggest{Text: "--amend", Alias: "-a", Description: "Amend an existing manifest list"},
		prompt.Suggest{Text: "--insecure", Description: "Allow communication with an insecure registry"},
	},
	"manifest inspect": {
		prompt.Suggest{Text: "--insecure", Description: "Allow communication with an insecure registry"},
		prompt.Suggest{Text: "--verbose", Alias: "-v", Description: "Output additional info including layers and platform"},
	},
	"manifest push": {
		prompt.Suggest{Text: "--insecure", Description: "Allow push to an insecure registry"},
		prompt.Suggest{Text: "--purge", Alias: "-p", Description: "Remove the local manifest list after push"},
	},
	"network connect": {
		prompt.Suggest{Text: "--alias", Description: "Add network-scoped alias for the container"},
		prompt.Suggest{Text: "--driver-opt", Description: "driver options for the network"},
		prompt.Suggest{Text: "--ip", Description: "IPv4 address (e.g., 172.30.100.104)"},
		prompt.Suggest{Text: "--ip6", Description: "IPv6 address (e.g., 2001:db8::33)"},
		prompt.Suggest{Text: "--link", Description: "Add link to another container"},
		prompt.Suggest{Text: "--link-local-ip", Description: "Add a link-local address for the container"},
	},
	"network create": {
		prompt.Suggest{Text: "--attachable", Description: "Enable manual container attachment"},
		prompt.Suggest{Text: "--aux-address", Description: "Auxiliary IPv4 or IPv6 addresses used by Network driver"},
		prompt.Suggest{Text: "--config-from", Description: "The network from which to copy the configuration"},
		prompt.Suggest{Text: "--config-only", Description: "Create a configuration only network"},
		prompt.Suggest{Text: "--driver", Alias: "-d", Description: "Driver to manage the Network"},
		prompt.Suggest{Text: "--gateway", Description: "IPv4 or IPv6 Gateway for the master subnet"},
		prompt.Suggest{Text: "--ingress", Description: "Create swarm routing-mesh network"},
		prompt.Suggest{Text: "--internal", Description: "Restrict external access to the network"},
		prompt.Suggest{Text: "--ip-range", Description: "Allocate container ip from a sub-range"},
		prompt.Suggest{Text: "--ipam-driver", Description: "IP Address Management Driver"},
		prompt.Suggest{Text: "--ipam-opt", Description: "Set IPAM driver specific options"},
		prompt.Suggest{Text: "--ipv6", Description: "Enable IPv6 networking"},
		prompt.Suggest{Text: "--label", Description: "Set metadata on a network"},
		prompt.Suggest{Text: "--opt", Alias: "-o", Description: "Set driver specific options"},
		prompt.Suggest{Text: "--scope", Description: "Control the network's scope"},
		prompt.Suggest{Text: "--subnet", Description: "Subnet in CIDR format that represents a network segment"},
	},
	"network disconnect": {
		prompt.Suggest{Text: "--force", Alias: "-f", Description: "Force the container to disconnect from a network"},
	},
	"network inspect": {
		prompt.Suggest{Text: "--format", Alias: "-f", Description: "Format the output using the given Go template"},
		prompt.Suggest{Text: "--verbose", Alias: "-v", Description: "Verbose output for diagnostics"},
	},
	"network ls": {
		prompt.Suggest{Text: "--filter", Alias: "-f", Description: "Provide filter values (e.g. 'driver=bridge')"},
		prompt.Suggest{Text: "--format", Description: "Pretty-print networks using a Go template"},
		prompt.Suggest{Text: "--no-trunc", Description: "Do not truncate the output"},
		prompt.Suggest{Text: "--quiet", Alias: "-q", Description: "Only display network IDs"},
	},
	"network prune": {
		prompt.Suggest{Text: "--filter", Description: "Provide filter values (e.g. 'until=<timestamp>')"},
		prompt.Suggest{Text: "--force", Alias: "-f", Description: "Do not prompt for confirmation"},
	},
	"node inspect": {
		prompt.Suggest{Text: "--format", Alias: "-f", Description: "Format the output using the given Go template"},
		prompt.Suggest{Text: "--pretty", Description: "Print the information in a human friendly format"},
	},
	"node ls": {
		prompt.Suggest{Text: "--filter", Alias: "-f", Description: "Filter output based on conditions provided"},
		prompt.Suggest{Text: "--format", Description: "Pretty-print networks using a Go template"},
		prompt.Suggest{Text: "--quiet", Alias: "-q", Description: "Only display network IDs"},
	},
	"node ps": {
		prompt.Suggest{Text: "--filter", Alias: "-f", Description: "Filter output based on conditions provided"},
		prompt.Suggest{Text: "--format", Description: "Pretty-print tasks using a Go template"},
		prompt.Suggest{Text: "--no-resolve", Description: "Do not map IDs to Names"},
		prompt.Suggest{Text: "--no-trunc", Description: "Do not truncate output"},
		prompt.Suggest{Text: "--quiet", Alias: "-q", Description: "Only display task IDs"},
	},
	"node rm": {
		prompt.Suggest{Text: "--force", Alias: "-f", Description: "Do not prompt for confirmation"},
	},
	"node update": {
		prompt.Suggest{Text: "--availability", Description: "Availability of the node ('active'|'pause'|'drain')"},
		prompt.Suggest{Text: "--label-add", Description: "Add or update a node label (key=value)"},
		prompt.Suggest{Text: "--label-rm", Description: "Remove a node label if exists"},
		prompt.Suggest{Text: "--role", Description: "Role of the node ('worker'|'manager')"},
	},
	"plugin create": {
		prompt.Suggest{Text: "--compress", Description: "Compress the context using gzip"},
	},
	"plugin disable": {
		prompt.Suggest{Text: "--force", Alias: "-f", Description: "Do not prompt for confirmation"},
	},
	"plugin enable": {
		prompt.Suggest{Text: "--timeout", Description: "HTTP client timeout (in seconds)"},
	},
	"plugin inspect": {
		prompt.Suggest{Text: "--format", Description: "Pretty-print networks using a Go template"},
	},
	"plugin install": {
		prompt.Suggest{Text: "--alias", Description: "Local name for plugin"},
		prompt.Suggest{Text: "--disable", Description: "Do not enable the plugin on install"},
		prompt.Suggest{Text: "--disable-content-trust", Description: "Skip image verification"},
		prompt.Suggest{Text: "--grant-all-permissions", Description: "Grant all permissions necessary to run the plugin"},
	},
	"plugin ls": {
		prompt.Suggest{Text: "--filter", Alias: "-f", Description: "Provide filter values (e.g. 'enabled=true')"},
		prompt.Suggest{Text: "--format", Description: "Pretty-print plugins using a Go template"},
		prompt.Suggest{Text: "--no-trunc", Description: "Don't truncate output"},
		prompt.Suggest{Text: "--quiet", Alias: "-q", Description: "Only display plugin IDs"},
	},
	"plugin rm": {
		prompt.Suggest{Text: "--force", Alias: "-f", Description: "Do not prompt for confirmation"},
	},
	"plugin upgrade": {
		prompt.Suggest{Text: "--disable-content-trust", Description: "Skip image verification"},
		prompt.Suggest{Text: "--grant-all-permissions", Description: "Grant all permissions necessary to run the plugin"},
		prompt.Suggest{Text: "--skip-remote-check", Description: "Do not check if specified remote plugin matches existing plugin image"},
	},
	"secret create": {
		prompt.Suggest{Text: "--driver", Alias: "-d", Description: "Secret driver"},
		prompt.Suggest{Text: "--label", Alias: "-l", Description: "Secret labels"},
		prompt.Suggest{Text: "--template-driver", Description: "Template driver"},
	},
	"secret inspect": {
		prompt.Suggest{Text: "--format", Description: "Pretty-print networks using a Go template"},
		prompt.Suggest{Text: "--pretty", Description: "Print the information in a human friendly format"},
	},
	"secret ls": {
		prompt.Suggest{Text: "--filter", Alias: "-f", Description: "Filter output based on conditions provided"},
		prompt.Suggest{Text: "--format", Description: "Pretty-print plugins using a Go template"},
		prompt.Suggest{Text: "--quiet", Alias: "-q", Description: "Only display plugin IDs"},
	},
	"service create": {
		prompt.Suggest{Text: "--config", Description: "Specify configurations to expose to the service"},
		prompt.Suggest{Text: "--constraint", Description: "Placement constraints"},
		prompt.Suggest{Text: "--container-label", Description: "Container labels"},
		prompt.Suggest{Text: "--credential-spec", Description: "Credential spec for managed service account (Windows only)"},
		prompt.Suggest{Text: "--detach", Description: "Exit immediately instead of waiting for the service to converge"},
		prompt.Suggest{Text: "--dns", Description: "Set custom DNS servers"},
		prompt.Suggest{Text: "--dns-option", Description: "Set DNS options"},
		prompt.Suggest{Text: "--dns-search", Description: "Set custom DNS search domains"},
		prompt.Suggest{Text: "--endpoint-mode", Description: "Endpoint mode (vip or dnsrr)"},
		prompt.Suggest{Text: "--entrypoint", Description: "Overwrite the default ENTRYPOINT of the image"},
		prompt.Suggest{Text: "--env", Description: "Set environment variables"},
		prompt.Suggest{Text: "--env-file", Description: "Read in a file of environment variables"},
		prompt.Suggest{Text: "--generic-resource", Description: "User defined resources"},
		prompt.Suggest{Text: "--group", Description: "Set one or more supplementary user groups for the container"},
		prompt.Suggest{Text: "--health-cmd", Description: "Command to run to check health"},
		prompt.Suggest{Text: "--health-interval", Description: "Time between running the check (ms|s|m|h)"},
		prompt.Suggest{Text: "--health-retries", Description: "Consecutive failures needed to report unhealthy"},
		prompt.Suggest{Text: "--health-start-period", Description: "Start period for the container to initialize before counting retries towards unstable (ms|s|m|h)"},
		prompt.Suggest{Text: "--health-timeout", Description: "Maximum time to allow one check to run (ms|s|m|h)"},
		prompt.Suggest{Text: "--host", Description: "Set one or more custom host-to-IP mappings (host:ip)"},
		prompt.Suggest{Text: "--hostname", Description: "Container hostname"},
		prompt.Suggest{Text: "--init", Description: "Use an init inside each service container to forward signals and reap processes"},
		prompt.Suggest{Text: "--isolation", Description: "Service container isolation mode"},
		prompt.Suggest{Text: "--label", Description: "Service labels"},
		prompt.Suggest{Text: "--limit-cpu", Description: "Limit CPUs"},
		prompt.Suggest{Text: "--limit-memory", Description: "Limit Memory"},
		prompt.Suggest{Text: "--log-driver", Description: "Logging driver for service"},
		prompt.Suggest{Text: "--log-opt", Description: "Logging driver options"},
		prompt.Suggest{Text: "--mode", Description: "Service mode (replicated or global)"},
		prompt.Suggest{Text: "--mount", Description: "Attach a filesystem mount to the service"},
		prompt.Suggest{Text: "--name", Description: "Service name"},
		prompt.Suggest{Text: "--network", Description: "Network attachments"},
		prompt.Suggest{Text: "--no-healthcheck", Description: "Disable any container-specified HEALTHCHECK"},
		prompt.Suggest{Text: "--no-resolve-image", Description: "Do not query the registry to resolve image digest and supported platforms"},
		prompt.Suggest{Text: "--placement-pref", Description: "Add a placement preference"},
		prompt.Suggest{Text: "--publish", Description: "Publish a port as a node port"},
		prompt.Suggest{Text: "--quiet", Description: "Suppress progress output"},
		prompt.Suggest{Text: "--read-only", Description: "Mount the container's root filesystem as read only"},
		prompt.Suggest{Text: "--replicas", Description: "Number of tasks"},
		prompt.Suggest{Text: "--replicas-max-per-node", Description: "Maximum number of tasks per node (default 0 = unlimited)"},
		prompt.Suggest{Text: "--reserve-cpu", Description: "Reserve CPUs"},
		prompt.Suggest{Text: "--reserve-memory", Description: "Reserve Memory"},
		prompt.Suggest{Text: "--restart-condition", Description: "Restart when condition is met (“none”|”on-failure”|”any”) (default “any”)"},
		prompt.Suggest{Text: "--restart-delay", Description: "Delay between restart attempts (ns|us|ms|s|m|h) (default 5s)"},
		prompt.Suggest{Text: "--restart-max-attempts", Description: "Maximum number of restarts before giving up"},
		prompt.Suggest{Text: "--restart-window", Description: "Window used to evaluate the restart policy (ns|us|ms|s|m|h)"},
		prompt.Suggest{Text: "--rollback-delay", Description: "Delay between task rollbacks (ns|us|ms|s|m|h) (default 0s)"},
		prompt.Suggest{Text: "--rollback-failure-action", Description: "Action on rollback failure (“pause”|”continue”) (default “pause”)"},
		prompt.Suggest{Text: "--rollback-max-failure-ratio", Description: "Failure rate to tolerate during a rollback (default 0)"},
		prompt.Suggest{Text: "--rollback-monitor", Description: "Duration after each task rollback to monitor for failure (ns|us|ms|s|m|h) (default 5s)"},
		prompt.Suggest{Text: "--rollback-order", Description: "Rollback order (“start-first”|”stop-first”) (default “stop-first”)"},
		prompt.Suggest{Text: "--rollback-parallelism", Description: "Maximum number of tasks rolled back simultaneously (0 to roll back all at once)"},
		prompt.Suggest{Text: "--secret", Description: "Specify secrets to expose to the service"},
		prompt.Suggest{Text: "--stop-grace-period", Description: "Time to wait before force killing a container (ns|us|ms|s|m|h) (default 10s)"},
		prompt.Suggest{Text: "--stop-signal", Description: "Signal to stop the container"},
		prompt.Suggest{Text: "--sysctl", Description: "Sysctl options"},
		prompt.Suggest{Text: "--tty", Description: "Allocate a pseudo-TTY"},
		prompt.Suggest{Text: "--update-delay", Description: "Delay between updates (ns|us|ms|s|m|h) (default 0s)"},
		prompt.Suggest{Text: "--update-failure-action", Description: "Action on update failure (“pause”|”continue”|”rollback”) (default “pause”)"},
		prompt.Suggest{Text: "--update-max-failure-ratio", Description: "Failure rate to tolerate during an update (default 0)"},
		prompt.Suggest{Text: "--update-monitor", Description: "Duration after each task update to monitor for failure (ns|us|ms|s|m|h) (default 5s)"},
		prompt.Suggest{Text: "--update-order", Description: "Update order (“start-first”|”stop-first”) (default “stop-first”)"},
		prompt.Suggest{Text: "--update-parallelism", Description: "Maximum number of tasks updated simultaneously (0 to update all at once)"},
		prompt.Suggest{Text: "--user", Description: "Username or UID (format: <name|uid>[:<group|gid>])"},
		prompt.Suggest{Text: "--with-registry-auth", Description: "Send registry authentication details to swarm agents"},
		prompt.Suggest{Text: "--workdir", Description: "Working directory inside the container"},
	},
	"service inspect": {
		prompt.Suggest{Text: "--format", Description: "Format the output using the given Go template"},
		prompt.Suggest{Text: "--pretty", Description: "Print the information in a human friendly format"},
	},
	"service logs": {
		prompt.Suggest{Text: "--details", Description: "Show extra details provided to logs"},
		prompt.Suggest{Text: "--follow", Description: "Follow log output"},
		prompt.Suggest{Text: "--no-resolve", Description: "Do not map IDs to Names in output"},
		prompt.Suggest{Text: "--no-task-ids", Description: "Do not include task IDs in output"},
		prompt.Suggest{Text: "--no-trunc", Description: "Do not truncate output"},
		prompt.Suggest{Text: "--raw", Description: "Do not neatly format logs"},
		prompt.Suggest{Text: "--since", Description: "Show logs since timestamp (e.g. 2013-01-02T13:23:37) or relative (e.g. 42m for 42 minutes)"},
		prompt.Suggest{Text: "--tail", Description: "Number of lines to show from the end of the logs"},
		prompt.Suggest{Text: "--timestamps", Description: "Show timestamps"},
	},
	"service ls": {
		prompt.Suggest{Text: "--filter", Alias: "-f", Description: "Filter output based on conditions provided"},
		prompt.Suggest{Text: "--format", Description: "Pretty-print services using a Go template"},
		prompt.Suggest{Text: "--quiet", Alias: "-q", Description: "Only display IDs"},
	},
	"service ps": {
		prompt.Suggest{Text: "--filter", Description: "Filter output based on conditions provided"},
		prompt.Suggest{Text: "--format", Description: "Pretty-print tasks using a Go template"},
		prompt.Suggest{Text: "--no-resolve", Description: "Do not map IDs to Names"},
		prompt.Suggest{Text: "--no-trunc", Description: "Do not truncate output"},
		prompt.Suggest{Text: "--quiet", Description: "Only display task IDs"},
	},
	"service rollback": {
		prompt.Suggest{Text: "--detach", Description: "Exit immediately instead of waiting for the service to converge"},
		prompt.Suggest{Text: "--quiet", Description: "Suppress progress output"},
	},
	"service scale": {
		prompt.Suggest{Text: "--detach", Description: "Exit immediately instead of waiting for the service to converge"},
	},
	"service update": {
		prompt.Suggest{Text: "--args", Description: "Service command args"},
		prompt.Suggest{Text: "--config-add", Description: "Add or update a config file on a service"},
		prompt.Suggest{Text: "--config-rm", Description: "Remove a configuration file"},
		prompt.Suggest{Text: "--constraint-add", Description: "Add or update a placement constraint"},
		prompt.Suggest{Text: "--constraint-rm", Description: "Remove a constraint"},
		prompt.Suggest{Text: "--container-label-add", Description: "Add or update a container label"},
		prompt.Suggest{Text: "--container-label-rm", Description: "Remove a container label by its key"},
		prompt.Suggest{Text: "--credential-spec", Description: "Credential spec for managed service account (Windows only)"},
		prompt.Suggest{Text: "--detach", Description: "Exit immediately instead of waiting for the service to converge"},
		prompt.Suggest{Text: "--dns-add", Description: "Add or update a custom DNS server"},
		prompt.Suggest{Text: "--dns-option-add", Description: "Add or update a DNS option"},
		prompt.Suggest{Text: "--dns-option-rm", Description: "Remove a DNS option"},
		prompt.Suggest{Text: "--dns-rm", Description: "Remove a custom DNS server"},
		prompt.Suggest{Text: "--dns-search-add", Description: "Add or update a custom DNS search domain"},
		prompt.Suggest{Text: "--dns-search-rm", Description: "Remove a DNS search domain"},
		prompt.Suggest{Text: "--endpoint-mode", Description: "Endpoint mode (vip or dnsrr)"},
		prompt.Suggest{Text: "--entrypoint", Description: "Overwrite the default ENTRYPOINT of the image"},
		prompt.Suggest{Text: "--env-add", Description: "Add or update an environment variable"},
		prompt.Suggest{Text: "--env-rm", Description: "Remove an environment variable"},
		prompt.Suggest{Text: "--force", Description: "Force update even if no changes require it"},
		prompt.Suggest{Text: "--generic-resource-add", Description: "Add a Generic resource"},
		prompt.Suggest{Text: "--generic-resource-rm", Description: "Remove a Generic resource"},
		prompt.Suggest{Text: "--group-add", Description: "Add an additional supplementary user group to the container"},
		prompt.Suggest{Text: "--group-rm", Description: "Remove a previously added supplementary user group from the container"},
		prompt.Suggest{Text: "--health-cmd", Description: "Command to run to check health"},
		prompt.Suggest{Text: "--health-interval", Description: "Time between running the check (ms|s|m|h)"},
		prompt.Suggest{Text: "--health-retries", Description: "Consecutive failures needed to report unhealthy"},
		prompt.Suggest{Text: "--health-start-period", Description: "Start period for the container to initialize before counting retries towards unstable (ms|s|m|h)"},
		prompt.Suggest{Text: "--health-timeout", Description: "Maximum time to allow one check to run (ms|s|m|h)"},
		prompt.Suggest{Text: "--host-add", Description: "Add a custom host-to-IP mapping (host:ip)"},
		prompt.Suggest{Text: "--host-rm", Description: "Remove a custom host-to-IP mapping (host:ip)"},
		prompt.Suggest{Text: "--hostname", Description: "Container hostname"},
		prompt.Suggest{Text: "--image", Description: "Service image tag"},
		prompt.Suggest{Text: "--init", Description: "Use an init inside each service container to forward signals and reap processes"},
		prompt.Suggest{Text: "--isolation", Description: "Service container isolation mode"},
		prompt.Suggest{Text: "--label-add", Description: "Add or update a service label"},
		prompt.Suggest{Text: "--label-rm", Description: "Remove a label by its key"},
		prompt.Suggest{Text: "--limit-cpu", Description: "Limit CPUs"},
		prompt.Suggest{Text: "--limit-memory", Description: "Limit Memory"},
		prompt.Suggest{Text: "--log-driver", Description: "Logging driver for service"},
		prompt.Suggest{Text: "--log-opt", Description: "Logging driver options"},
		prompt.Suggest{Text: "--mount-add", Description: "Add or update a mount on a service"},
		prompt.Suggest{Text: "--mount-rm", Description: "Remove a mount by its target path"},
		prompt.Suggest{Text: "--network-add", Description: "Add a network"},
		prompt.Suggest{Text: "--network-rm", Description: "Remove a network"},
		prompt.Suggest{Text: "--no-healthcheck", Description: "Disable any container-specified HEALTHCHECK"},
		prompt.Suggest{Text: "--no-resolve-image", Description: "Do not query the registry to resolve image digest and supported platforms"},
		prompt.Suggest{Text: "--placement-pref-add", Description: "Add a placement preference"},
		prompt.Suggest{Text: "--placement-pref-rm", Description: "Remove a placement preference"},
		prompt.Suggest{Text: "--publish-add", Description: "Add or update a published port"},
		prompt.Suggest{Text: "--publish-rm", Description: "Remove a published port by its target port"},
		prompt.Suggest{Text: "--quiet", Description: "Suppress progress output"},
		prompt.Suggest{Text: "--read-only", Description: "Mount the container's root filesystem as read only"},
		prompt.Suggest{Text: "--replicas", Description: "Number of tasks"},
		prompt.Suggest{Text: "--replicas-max-per-node", Description: "Maximum number of tasks per node (default 0 = unlimited)"},
		prompt.Suggest{Text: "--reserve-cpu", Description: "Reserve CPUs"},
		prompt.Suggest{Text: "--reserve-memory", Description: "Reserve Memory"},
		prompt.Suggest{Text: "--restart-condition", Description: "Restart when condition is met (“none”|”on-failure”|”any”)"},
		prompt.Suggest{Text: "--restart-delay", Description: "Delay between restart attempts (ns|us|ms|s|m|h)"},
		prompt.Suggest{Text: "--restart-max-attempts", Description: "Maximum number of restarts before giving up"},
		prompt.Suggest{Text: "--restart-window", Description: "Window used to evaluate the restart policy (ns|us|ms|s|m|h)"},
		prompt.Suggest{Text: "--rollback", Description: "Rollback to previous specification"},
		prompt.Suggest{Text: "--rollback-delay", Description: "Delay between task rollbacks (ns|us|ms|s|m|h)"},
		prompt.Suggest{Text: "--rollback-failure-action", Description: "Action on rollback failure (“pause”|”continue”)"},
		prompt.Suggest{Text: "--rollback-max-failure-ratio", Description: "Failure rate to tolerate during a rollback"},
		prompt.Suggest{Text: "--rollback-monitor", Description: "Duration after each task rollback to monitor for failure (ns|us|ms|s|m|h)"},
		prompt.Suggest{Text: "--rollback-order", Description: "Rollback order (“start-first”|”stop-first”)"},
		prompt.Suggest{Text: "--rollback-parallelism", Description: "Maximum number of tasks rolled back simultaneously (0 to roll back all at once)"},
		prompt.Suggest{Text: "--secret-add", Description: "Add or update a secret on a service"},
		prompt.Suggest{Text: "--secret-rm", Description: "Remove a secret"},
		prompt.Suggest{Text: "--stop-grace-period", Description: "Time to wait before force killing a container (ns|us|ms|s|m|h)"},
		prompt.Suggest{Text: "--stop-signal", Description: "Signal to stop the container"},
		prompt.Suggest{Text: "--sysctl-add", Description: "Add or update a Sysctl option"},
		prompt.Suggest{Text: "--sysctl-rm", Description: "Remove a Sysctl option"},
		prompt.Suggest{Text: "--tty", Description: "Allocate a pseudo-TTY"},
		prompt.Suggest{Text: "--update-delay", Description: "Delay between updates (ns|us|ms|s|m|h)"},
		prompt.Suggest{Text: "--update-failure-action", Description: "Action on update failure (“pause”|”continue”|”rollback”)"},
		prompt.Suggest{Text: "--update-max-failure-ratio", Description: "Failure rate to tolerate during an update"},
		prompt.Suggest{Text: "--update-monitor", Description: "Duration after each task update to monitor for failure (ns|us|ms|s|m|h)"},
		prompt.Suggest{Text: "--update-order", Description: "Update order (“start-first”|”stop-first”)"},
		prompt.Suggest{Text: "--update-parallelism", Description: "Maximum number of tasks updated simultaneously (0 to update all at once)"},
		prompt.Suggest{Text: "--user", Description: "Username or UID (format: <name|uid>[:<group|gid>])"},
		prompt.Suggest{Text: "--with-registry-auth", Description: "Send registry authentication details to swarm agents"},
		prompt.Suggest{Text: "--workdir", Description: "Working directory inside the container"},
	},
	"stack deploy": {
		prompt.Suggest{Text: "--compose-file", Alias: "-c", Description: "Path to a Compose file, or to read from stdin"},
		prompt.Suggest{Text: "--namespace", Description: "Kubernetes namespace to use"},
		prompt.Suggest{Text: "--prune", Description: "Prune services that are no longer referenced"},
		prompt.Suggest{Text: "--resolve-image", Description: "Query the registry to resolve image digest and supported platforms (\"always\"|\"changed\"|\"never\")"},
		prompt.Suggest{Text: "--with-registry-auth", Description: "Send registry authentication details to Swarm agents"},
		prompt.Suggest{Text: "--kubeconfig", Description: "Kubernetes config file"},
		prompt.Suggest{Text: "--orchestrator", Description: "Orchestrator to use (swarm|kubernetes|all)"},
	},
	"stack ps": {
		prompt.Suggest{Text: "--filter", Alias: "-f", Description: "Filter output based on conditions provided"},
		prompt.Suggest{Text: "--format", Description: "Pretty-print tasks using a Go template"},
		prompt.Suggest{Text: "--namespace", Description: "Kubernetes namespace to use"},
		prompt.Suggest{Text: "--no-resolve", Description: "Do not map IDs to Names"},
		prompt.Suggest{Text: "--no-trunc", Description: "Do not truncate output"},
		prompt.Suggest{Text: "--quiet", Alias: "-q", Description: "Only display task IDs"},
		prompt.Suggest{Text: "--kubeconfig", Description: "Kubernetes config file"},
		prompt.Suggest{Text: "--orchestrator", Description: "Orchestrator to use (swarm|kubernetes|all)"},
	},
	"stack rm": {
		prompt.Suggest{Text: "--namespace", Description: "Kubernetes namespace to use"},
		prompt.Suggest{Text: "--kubeconfig", Description: "Kubernetes config file"},
		prompt.Suggest{Text: "--orchestrator", Description: "Orchestrator to use (swarm|kubernetes|all)"},
	},
	"stack services": {
		prompt.Suggest{Text: "--filter", Alias: "-f", Description: "Filter output based on conditions provided"},
		prompt.Suggest{Text: "--format", Description: "Pretty-print services using a Go template"},
		prompt.Suggest{Text: "--namespace", Description: "Kubernetes namespace to use"},
		prompt.Suggest{Text: "--quiet", Alias: "-q", Description: "Only display IDs"},
		prompt.Suggest{Text: "--kubeconfig", Description: "Kubernetes config file"},
		prompt.Suggest{Text: "--orchestrator", Description: "Orchestrator to use (swarm|kubernetes|all)"},
	},
	"system df": {
		prompt.Suggest{Text: "--format", Description: "Pretty-print images using a Go template"},
		prompt.Suggest{Text: "--verbose", Description: "Show detailed information on space usage"},
	},
	"system events": {
		prompt.Suggest{Text: "--filter", Alias: "-f", Description: "Filter output based on conditions provided"},
		prompt.Suggest{Text: "--format", Description: "Format the output using the given Go template"},
		prompt.Suggest{Text: "--since", Description: "Show all events created since timestamp"},
		prompt.Suggest{Text: "--until", Description: "Stream events until this timestamp"},
	},
	"system info": {
		prompt.Suggest{Text: "--format", Alias: "-f", Description: "Format the output using the given Go template"},
	},
	"system prune": {
		prompt.Suggest{Text: "--all", Alias: "-a", Description: "Remove all unused images not just dangling ones"},
		prompt.Suggest{Text: "--filter", Description: "Provide filter values (e.g. 'label=<key>=<value>')"},
		prompt.Suggest{Text: "--force", Alias: "-f", Description: "Do not prompt for confirmation"},
		prompt.Suggest{Text: "--volumes", Description: "Prune volumes"},
	},
	"trust inspect": {
		prompt.Suggest{Text: "--pretty", Description: "Print the information in a human friendly format"},
	},
	"trust revoke": {
		prompt.Suggest{Text: "--yes", Alias: "-y", Description: "Do not prompt for confirmation"},
	},
	"trust sign": {
		prompt.Suggest{Text: "--local", Description: "Sign a locally tagged image"},
	},
	"volume create": {
		prompt.Suggest{Text: "--driver", Alias: "-d", Description: "Specify volume driver name"},
		prompt.Suggest{Text: "--label", Description: "Set metadata for a volume"},
		prompt.Suggest{Text: "--name", Description: "Specify volume name"},
		prompt.Suggest{Text: "--opt", Alias: "-o", Description: "Set driver specific options"},
	},
	"volume inspect": {
		prompt.Suggest{Text: "--format", Alias: "-f", Description: "Format the output using the given Go template"},
	},
	"volume ls": {
		prompt.Suggest{Text: "--filter", Alias: "-f", Description: "Filter output based on conditions provided"},
		prompt.Suggest{Text: "--format", Description: "Pretty-print services using a Go template"},
		prompt.Suggest{Text: "--quiet", Alias: "-q", Description: "Only display IDs"},
	},
	"volume prune": {
		prompt.Suggest{Text: "--filter", Description: "Provide filter values (e.g. 'label=<key>=<value>')"},
		prompt.Suggest{Text: "--force", Alias: "-f", Description: "Do not prompt for confirmation"},
	},
	"volume rm": {
		prompt.Suggest{Text: "--force", Alias: "-f", Description: "Do not prompt for confirmation"},
	},
}
